@@ -1,3 +1,5 @@
+# encoding: utf-8
+
 # Welcome to Prawn, the best PDF Generation library ever.
 # This documentation covers user level functionality.
 #
@@ -7,8 +9,6 @@ require 'ttfunk'
 require "pdf/core"
 
 module Prawn
-  VERSION = "1.0.0"
-
   extend self
 
   file = __FILE__
@@ -20,7 +20,7 @@ module Prawn
   #
   BASEDIR = File.expand_path(File.join(dir, '..'))
   DATADIR = File.expand_path(File.join(dir, '..', 'data'))
-  
+
   FLOAT_PRECISION = 1.0e-9
 
   # Whe set to true, Prawn will verify hash options to ensure only valid keys
@@ -36,10 +36,10 @@ module Prawn
 
   def verify_options(accepted, actual) # @private
     return unless debug || $DEBUG
-    unless (act=Set[*actual.keys]).subset?(acc=Set[*accepted])
-      raise Prawn::Errors::UnknownOption,
-        "\nDetected unknown option(s): #{(act - acc).to_a.inspect}\n" <<
-        "Accepted options are: #{accepted.inspect}"
+    unless (act = Set[*actual.keys]).subset?(acc = Set[*accepted])
+      fail Prawn::Errors::UnknownOption,
+           "\nDetected unknown option(s): #{(act - acc).to_a.inspect}\n" \
+           "Accepted options are: #{accepted.inspect}"
     end
     yield if block_given?
   end
@@ -62,8 +62,9 @@ module Prawn
   end
 end
 
-require_relative "prawn/errors"
+require_relative "prawn/version"
 
+require_relative "prawn/errors"
 
 require_relative "prawn/utilities"
 require_relative "prawn/text"
@@ -77,15 +78,12 @@ require_relative "prawn/soft_mask"
 require_relative "prawn/security"
 require_relative "prawn/document"
 require_relative "prawn/font"
-require_relative "prawn/encoding"
 require_relative "prawn/measurements"
 require_relative "prawn/repeater"
 require_relative "prawn/outline"
-require_relative "prawn/layout"
-
+require_relative "prawn/grid"
+require_relative "prawn/view"
 require_relative "prawn/image_handler"
 
-
-
 Prawn.image_handler.register(Prawn::Images::PNG)
 Prawn.image_handler.register(Prawn::Images::JPG)
