@@ -8,31 +8,28 @@
 #
 
 module Prawn
-
   # Cache used internally by Prawn::Document instances to calculate the width
   # of various strings for layout purposes.
   #
   # @private
   class FontMetricCache
+    CacheEntry = Struct.new(:font, :options, :string)
 
-    CacheEntry = Struct.new( :font, :options, :string )
-
-    def initialize( document )
+    def initialize(document)
       @document = document
 
       @cache = {}
     end
 
-    def width_of( string, options )
+    def width_of(string, options)
       f = if options[:style]
             # override style with :style => :bold
-            @document.find_font(@document.font ? @document.font.name : 'Helvetica',
-                      :style => options[:style])
+            @document.find_font(@document.font.family, :style => options[:style])
           else
             @document.font
           end
 
-      key = CacheEntry.new( f, options, string )
+      key = CacheEntry.new(f, options, string)
 
       unless length = @cache[ key ]
         length = @cache[ key ] = f.compute_width_of(string, options)
@@ -41,7 +38,5 @@ module Prawn
       length +
         (@document.character_spacing * @document.font.character_count(string))
     end
-
   end
-
 end
