@@ -6,7 +6,6 @@
 #
 # This is free software. Please see the LICENSE and COPYING files for details.
 
-
 require_relative "graphics/color"
 require_relative "graphics/dash"
 require_relative "graphics/cap_style"
@@ -16,7 +15,6 @@ require_relative "graphics/transformation"
 require_relative "graphics/patterns"
 
 module Prawn
-
   # Implements the drawing facilities for Prawn::Document.
   # Use this to draw the most beautiful imaginable things.
   #
@@ -24,7 +22,6 @@ module Prawn
   # ruby-pdf.rubyforge.org
   #
   module Graphics
-
     include Color
     include Dash
     include CapStyle
@@ -46,8 +43,8 @@ module Prawn
     #   pdf.move_to(100,50)
     #
     def move_to(*point)
-      x,y = map_to_absolute(point)
-      renderer.add_content("%.3f %.3f m" % [ x, y ])
+      xy = PDF::Core.real_params(map_to_absolute(point))
+      renderer.add_content("#{xy} m")
     end
 
     # Draws a line from the current drawing position to the specified point.
@@ -57,8 +54,8 @@ module Prawn
     #   pdf.line_to(50,50)
     #
     def line_to(*point)
-      x,y = map_to_absolute(point)
-      renderer.add_content("%.3f %.3f l" % [ x, y ])
+      xy = PDF::Core.real_params(map_to_absolute(point))
+      renderer.add_content("#{xy} l")
     end
 
     # Draws a Bezier curve from the current drawing position to the
@@ -66,14 +63,16 @@ module Prawn
     #
     #   pdf.curve_to [100,100], :bounds => [[90,90],[75,75]]
     #
-    def curve_to(dest,options={})
-       options[:bounds] or raise Prawn::Errors::InvalidGraphicsPath,
-         "Bounding points for bezier curve must be specified "+
-         "as :bounds => [[x1,y1],[x2,y2]]"
+    def curve_to(dest, options = {})
+      options[:bounds] or fail Prawn::Errors::InvalidGraphicsPath,
+                               "Bounding points for bezier curve must be specified " \
+                               "as :bounds => [[x1,y1],[x2,y2]]"
 
-       curve_points = (options[:bounds] << dest).map { |e| map_to_absolute(e) }
-       renderer.add_content("%.3f %.3f %.3f %.3f %.3f %.3f c" %
-                     curve_points.flatten )
+      curve_points = PDF::Core.real_params(
+        (options[:bounds] << dest).flat_map { |e| map_to_absolute(e) }
+      )
+
+      renderer.add_content("#{curve_points} c")
     end
 
     # Draws a rectangle given <tt>point</tt>, <tt>width</tt> and
@@ -81,9 +80,11 @@ module Prawn
     #
     #    pdf.rectangle [300,300], 100, 200
     #
-    def rectangle(point,width,height)
-      x,y = map_to_absolute(point)
-      renderer.add_content("%.3f %.3f %.3f %.3f re" % [ x, y - height, width, height ])
+    def rectangle(point, width, height)
+      x, y = map_to_absolute(point)
+      box = PDF::Core.real_params([x, y - height, width, height])
+
+      renderer.add_content("#{box} re")
     end
 
     # Draws a rounded rectangle given <tt>point</tt>, <tt>width</tt> and
@@ -92,12 +93,11 @@ module Prawn
     #
     #    pdf.rounded_rectangle [300,300], 100, 200, 10
     #
-    def rounded_rectangle(point,width,height,radius)
+    def rounded_rectangle(point, width, height, radius)
       x, y = point
       rounded_polygon(radius, point, [x + width, y], [x + width, y - height], [x, y - height])
     end
 
-
     ###########################################################
     #  Higher level functions: May use relative coords        #
     ###########################################################
@@ -117,7 +117,7 @@ module Prawn
     #   pdf.line_width(5)
     #   pdf.line_width #=> 5
     #
-    def line_width(width=nil)
+    def line_width(width = nil)
       if width
         self.line_width = width
       else
@@ -132,7 +132,7 @@ module Prawn
     #   pdf.line(100,100,200,250)
     #
     def line(*points)
-      x0,y0,x1,y1 = points.flatten
+      x0, y0, x1, y1 = points.flatten
       move_to(x0, y0)
       line_to(x1, y1)
     end
@@ -143,14 +143,14 @@ module Prawn
     #  # draw a line from [25, 75] to [100, 75]
     #  horizontal_line 25, 100, :at => 75
     #
-    def horizontal_line(x1,x2,options={})
+    def horizontal_line(x1, x2, options = {})
       if options[:at]
         y1 = options[:at]
       else
         y1 = y - bounds.absolute_bottom
       end
 
-      line(x1,y1,x2,y1)
+      line(x1, y1, x2, y1)
     end
 
     # Draws a horizontal line from the left border to the right border of the
@@ -165,8 +165,8 @@ module Prawn
     #   # draw a line from [25, 100] to [25, 300]
     #   vertical_line 100, 300, :at => 25
     #
-    def vertical_line(y1,y2,params)
-      line(params[:at],y1,params[:at],y2)
+    def vertical_line(y1, y2, params)
+      line(params[:at], y1, params[:at], y2)
     end
 
     # Draws a Bezier curve between two points, bounded by two additional
@@ -174,9 +174,9 @@ module Prawn
     #
     #    pdf.curve [50,100], [100,100], :bounds => [[90,90],[75,75]]
     #
-    def curve(origin,dest, options={})
+    def curve(origin, dest, options = {})
       move_to(*origin)
-      curve_to(dest,options)
+      curve_to(dest, options)
     end
 
     # This constant is used to approximate a symmetrical arc using a cubic
@@ -211,19 +211,19 @@ module Prawn
 
       # Upper right hand corner
       curve_to [x,  y + r2],
-        :bounds => [[x + r1, y + l2], [x + l1, y + r2]]
+               :bounds => [[x + r1, y + l2], [x + l1, y + r2]]
 
       # Upper left hand corner
       curve_to [x - r1, y],
-        :bounds => [[x - l1, y + r2], [x - r1, y + l2]]
+               :bounds => [[x - l1, y + r2], [x - r1, y + l2]]
 
       # Lower left hand corner
       curve_to [x, y - r2],
-        :bounds => [[x - r1, y - l2], [x - l1, y - r2]]
+               :bounds => [[x - r1, y - l2], [x - l1, y - r2]]
 
       # Lower right hand corner
       curve_to [x + r1, y],
-        :bounds => [[x + l1, y - r2], [x + r1, y - l2]]
+               :bounds => [[x + l1, y - r2], [x + r1, y - l2]]
 
       move_to(x, y)
     end
@@ -258,15 +258,14 @@ module Prawn
       renderer.add_content "h"
     end
 
-
     # Creates a rounded vertex for a line segment used for building a rounded polygon
     # requires a radius to define bezier curve and three points. The first two points define
     # the line segment and the third point helps define the curve for the vertex.
     def rounded_vertex(radius, *points)
       radial_point_1 = point_on_line(radius, points[0], points[1])
-      bezier_point_1 = point_on_line((radius - radius*KAPPA), points[0], points[1] )
+      bezier_point_1 = point_on_line((radius - radius * KAPPA), points[0], points[1])
       radial_point_2 = point_on_line(radius, points[2], points[1])
-      bezier_point_2 = point_on_line((radius - radius*KAPPA), points[2], points[1])
+      bezier_point_2 = point_on_line((radius - radius * KAPPA), points[2], points[1])
       line_to(radial_point_1)
       curve_to(radial_point_2, :bounds => [bezier_point_1, bezier_point_2])
     end
@@ -319,12 +318,12 @@ module Prawn
     #
     def stroke_axis(options = {})
       options = {
-        :at => [0,0],
-        :height => bounds.height.to_i - (options[:at] || [0,0])[1],
-        :width => bounds.width.to_i - (options[:at] || [0,0])[0],
+        :at => [0, 0],
+        :height => bounds.height.to_i - (options[:at] || [0, 0])[1],
+        :width => bounds.width.to_i - (options[:at] || [0, 0])[0],
         :step_length => 100,
         :negative_axes_length => 20,
-        :color => "000000",
+        :color => "000000"
       }.merge(options)
 
       Prawn.verify_options([:at, :width, :height, :step_length,
@@ -362,7 +361,7 @@ module Prawn
     # will be used. See the PDF reference, "Graphics -> Path Construction and
     # Painting -> Clipping Path Operators" for details on the difference.
     #
-    def fill(options={})
+    def fill(options = {})
       yield if block_given?
       renderer.add_content(options[:fill_rule] == :even_odd ? "f*" : "f")
     end
@@ -376,7 +375,7 @@ module Prawn
     # will be used. See the PDF reference, "Graphics -> Path Construction and
     # Painting -> Clipping Path Operators" for details on the difference.
     #
-    def fill_and_stroke(options={})
+    def fill_and_stroke(options = {})
       yield if block_given?
       renderer.add_content(options[:fill_rule] == :even_odd ? "b*" : "b")
     end
@@ -597,7 +596,7 @@ module Prawn
     shapes = %w{line_to curve_to rectangle rounded_rectangle line horizontal_line horizontal_rule vertical_line
                 curve circle_at circle ellipse_at ellipse polygon rounded_polygon rounded_vertex}
 
-    ops.product(shapes).each do |operation,shape|
+    ops.product(shapes).each do |operation, shape|
       class_eval "def #{operation}_#{shape}(*args); #{shape}(*args); #{operation}; end"
     end
 
@@ -616,7 +615,7 @@ module Prawn
     end
 
     def map_to_absolute(*point)
-      x,y = point.flatten
+      x, y = point.flatten
       [@bounding_box.absolute_left + x, @bounding_box.absolute_bottom + y]
     end
 
@@ -625,19 +624,18 @@ module Prawn
     end
 
     def degree_to_rad(angle)
-       angle * Math::PI / 180
+      angle * Math::PI / 180
     end
 
     # Returns the coordinates for a point on a line that is a given distance away from the second
     # point defining the line segement
     def point_on_line(distance_from_end, *points)
-      x0,y0,x1,y1 = points.flatten
+      x0, y0, x1, y1 = points.flatten
       length = Math.sqrt((x1 - x0)**2 + (y1 - y0)**2)
       p = (length - distance_from_end) / length
-      xr = x0 + p*(x1 - x0)
-      yr = y0 + p*(y1 - y0)
+      xr = x0 + p * (x1 - x0)
+      yr = y0 + p * (y1 - y0)
       [xr, yr]
     end
-
   end
 end
