@@ -68,13 +68,9 @@ module Prawn
             @transparency = {}
             case @color_type
             when 3
-              # Indexed colour, RGB. Each byte in this chunk is an alpha for
-              # the palette index in the PLTE ("palette") chunk up until the
-              # last non-opaque entry. Set up an array, stretching over all
-              # palette entries which will be 0 (opaque) or 1 (transparent).
-              @transparency[:indexed]  = data.read(chunk_size).unpack("C*")
-              short = 255 - @transparency[:indexed].size
-              @transparency[:indexed] += ([255] * short) if short > 0
+              fail Errors::UnsupportedImageType,
+                   "Pallete-based transparency in PNG is not currently supported.\n" \
+                   "See https://github.com/prawnpdf/prawn/issues/783"
             when 0
               # Greyscale. Corresponding to entries in the PLTE chunk.
               # Grey is two bytes, range 0 .. (2 ^ bit-depth) - 1
@@ -125,18 +121,18 @@ module Prawn
       #
       def build_pdf_object(document)
         if compression_method != 0
-          raise Errors::UnsupportedImageType,
-            'PNG uses an unsupported compression method'
+          fail Errors::UnsupportedImageType,
+               'PNG uses an unsupported compression method'
         end
 
         if filter_method != 0
-          raise Errors::UnsupportedImageType,
-            'PNG uses an unsupported filter method'
+          fail Errors::UnsupportedImageType,
+               'PNG uses an unsupported filter method'
         end
 
         if interlace_method != 0
-          raise Errors::UnsupportedImageType,
-            'PNG uses unsupported interlace method'
+          fail Errors::UnsupportedImageType,
+               'PNG uses unsupported interlace method'
         end
 
         # some PNG types store the colour and alpha channel data together,
@@ -149,8 +145,8 @@ module Prawn
         when 3
           color = :DeviceRGB
         else
-          raise Errors::UnsupportedImageType,
-            "PNG uses an unsupported number of colors (#{png.colors})"
+          fail Errors::UnsupportedImageType,
+               "PNG uses an unsupported number of colors (#{png.colors})"
         end
 
         # build the image dict
@@ -185,7 +181,7 @@ module Prawn
           # build the color space array for the image
           obj.data[:ColorSpace] = [:Indexed,
                                    :DeviceRGB,
-                                   (palette.size / 3) -1,
+                                   (palette.size / 3) - 1,
                                    palette_obj]
         end
 
@@ -207,12 +203,7 @@ module Prawn
           # - An array with N elements, where N is two times the number of color
           #   components.
           rgb = transparency[:rgb]
-          obj.data[:Mask] = rgb.collect { |x| [x,x] }.flatten
-        elsif transparency[:indexed]
-          # TODO: broken. I was attempting to us Color Key Masking, but I think
-          #       we need to construct an SMask i think. Maybe do it inside
-          #       the PNG class, and store it in alpha_channel
-          #obj.data[:Mask] = transparency[:indexed]
+          obj.data[:Mask] = rgb.collect { |x| [x, x] }.flatten
         end
 
         # For PNG color types 4 and 6, the transparency data is stored as a alpha
