@@ -11,10 +11,8 @@
 module Prawn
   module Text
     module Formatted #:nodoc:
-
       # @private
       class LineWrap #:nodoc:
-
         # The width of the last wrapped line
         #
         def width
@@ -29,6 +27,10 @@ module Prawn
           @newline_encountered || is_next_string_newline? || @arranger.finished?
         end
 
+        def tokenize(fragment)
+          fragment.scan(scan_pattern)
+        end
+
         # Work in conjunction with the PDF::Formatted::Arranger
         # defined in the :arranger option to determine what formatted text
         # will fit within the width defined by the :width option
@@ -79,7 +81,7 @@ module Prawn
           result
         end
 
-        # returns true iff all text was printed without running into the end of
+        # returns true if all text was printed without running into the end of
         # the line
         #
         def add_fragment_to_line(fragment)
@@ -89,7 +91,7 @@ module Prawn
             @newline_encountered = true
             false
           else
-            fragment.scan(scan_pattern).each do |segment|
+            tokenize(fragment).each do |segment|
               if segment == zero_width_space
                 segment_width = 0
               else
@@ -98,6 +100,10 @@ module Prawn
 
               if @accumulated_width + segment_width <= @width
                 @accumulated_width += segment_width
+                if segment[-1] == soft_hyphen
+                  sh_width = @document.width_of("#{soft_hyphen}", :kerning => @kerning)
+                  @accumulated_width -= sh_width
+                end
                 @fragment_output += segment
               else
                 end_of_the_line_reached(segment)
@@ -114,12 +120,13 @@ module Prawn
         # The pattern used to determine chunks of text to place on a given line
         #
         def scan_pattern
-          pattern = "[^#{break_chars}]+#{soft_hyphen}|" +
-            "[^#{break_chars}]+#{hyphen}+|" +
-            "[^#{break_chars}]+|" +
-            "[#{whitespace}]+|" +
-            "#{hyphen}+[^#{break_chars}]*|" +
+          pattern = "[^#{break_chars}]+#{soft_hyphen}|" \
+            "[^#{break_chars}]+#{hyphen}+|" \
+            "[^#{break_chars}]+|" \
+            "[#{whitespace}]+|" \
+            "#{hyphen}+[^#{break_chars}]*|" \
             "#{soft_hyphen}"
+
           Regexp.new(pattern)
         end
 
@@ -143,13 +150,8 @@ module Prawn
           "-"
         end
 
-        def soft_hyphen
-          @soft_hyphen
-        end
-
-        def zero_width_space
-          @zero_width_space
-        end
+        attr_reader :soft_hyphen
+        attr_reader :zero_width_space
 
         def line_empty?
           @line_empty && @accumulated_width == 0
@@ -160,6 +162,8 @@ module Prawn
           @kerning = options[:kerning]
           @width = options[:width]
 
+          @disable_wrap_by_char = options[:disable_wrap_by_char]
+
           @accumulated_width = 0
           @line_empty = true
           @line_contains_more_than_one_word = false
@@ -191,19 +195,15 @@ module Prawn
           remember_this_fragment_for_backward_looking_ops
         end
 
-        def update_output_based_on_last_fragment(fragment, normalized_soft_hyphen=nil)
+        def update_output_based_on_last_fragment(fragment, normalized_soft_hyphen = nil)
           remaining_text = fragment.slice(@fragment_output.length..fragment.length)
-          raise Prawn::Errors::CannotFit if line_finished? && line_empty? &&
-            @fragment_output.empty? && !fragment.strip.empty?
+          fail Prawn::Errors::CannotFit if line_finished? && line_empty? && @fragment_output.empty? && !fragment.strip.empty?
           @arranger.update_last_string(@fragment_output, remaining_text, normalized_soft_hyphen)
         end
 
         def determine_whether_to_pull_preceding_fragment_to_join_this_one(current_fragment)
-          if @fragment_output.empty? &&
-              !current_fragment.empty? &&
-              @line_contains_more_than_one_word
-            unless previous_fragment_ended_with_breakable? ||
-                fragment_begins_with_breakable?(current_fragment)
+          if @fragment_output.empty? && !current_fragment.empty? && @line_contains_more_than_one_word
+            unless previous_fragment_ended_with_breakable? || fragment_begins_with_breakable?(current_fragment)
               @fragment_output = @previous_fragment_output_without_last_word
               update_output_based_on_last_fragment(@previous_fragment)
             end
@@ -237,18 +237,18 @@ module Prawn
 
         def end_of_the_line_reached(segment)
           update_line_status_based_on_last_output
-          wrap_by_char(segment) unless @line_contains_more_than_one_word
+          wrap_by_char(segment) unless @disable_wrap_by_char || @line_contains_more_than_one_word
           @line_full = true
         end
 
         def wrap_by_char(segment)
           font = @document.font
           segment.each_char do |char|
-            break unless append_char(char,font)
+            break unless append_char(char, font)
           end
         end
 
-        def append_char(char,font)
+        def append_char(char, font)
           # kerning doesn't make sense in the context of a single character
           char_width = font.compute_width_of(char)
 
