@@ -6,9 +6,7 @@ require File.expand_path(File.join(File.dirname(__FILE__),
                                    %w[.. example_helper]))
 
 Prawn::ManualBuilder::Example.generate("text.pdf", :page_size => "FOLIO") do
-
   package "text" do |p|
-
     p.section "Basics" do |s|
       s.example "free_flowing_text"
       s.example "positioned_text"
@@ -42,7 +40,7 @@ Prawn::ManualBuilder::Example.generate("text.pdf", :page_size => "FOLIO") do
       s.example "registering_families"
     end
 
-    p.section "M17n" do |s|
+    p.section "Multilingualization" do |s|
       s.example "utf8"
       s.example "line_wrapping"
       s.example "right_to_left_text"
@@ -68,6 +66,5 @@ Prawn::ManualBuilder::Example.generate("text.pdf", :page_size => "FOLIO") do
             "What happens when rendering text in different languages"
           )
     end
-
   end
 end
