@@ -9,7 +9,7 @@
 # (the text font size will be shrunk to fit).
 #
 # If <code>:shrink_to_fit</code> mode is used with the
-# <code>:min_font_size</code> option set. The font size will not be reduced to
+# <code>:min_font_size</code> option set, the font size will not be reduced to
 # less than the value provided even if it means truncating some text.
 #
 # If the <code>:disable_wrap_by_char</code> is set to <code>true</code>
@@ -29,8 +29,9 @@ Prawn::ManualBuilder::Example.generate(filename) do
   y_position = cursor - 20
   [:truncate, :expand, :shrink_to_fit].each_with_index do |mode, i|
     text_box string, :at => [i * 150, y_position],
-             :width => 100, :height => 50,
-             :overflow => mode
+                     :width => 100,
+                     :height => 50,
+                     :overflow => mode
   end
 
   string = "If the box is too small for the text, :shrink_to_fit " +
@@ -41,8 +42,9 @@ Prawn::ManualBuilder::Example.generate(filename) do
   y_position = cursor - 20
   [nil, 8, 10, 12].each_with_index do |value, index|
     text_box string, :at => [index * 150, y_position],
-             :width => 50, :height => 50,
-             :overflow => :shrink_to_fit,
-             :min_font_size => value
+                     :width => 50,
+                     :height => 50,
+                     :overflow => :shrink_to_fit,
+                     :min_font_size => value
   end
 end
