@@ -2,73 +2,66 @@
 
 require File.join(File.expand_path(File.dirname(__FILE__)), "spec_helper")
 
-
 describe "When creating annotations" do
-
   before(:each) { create_pdf }
 
   it "should append annotation to current page" do
     @pdf.start_new_page
-    @pdf.annotate(:Rect => [0,0,10,10], :Subtype => :Text, :Contents => "Hello world!")
+    @pdf.annotate(:Rect => [0, 0, 10, 10], :Subtype => :Text, :Contents => "Hello world!")
     PDF::Reader.open(StringIO.new(@pdf.render)) do |pdf|
-      pdf.page(1).attributes[:Annots].should be_nil
-      pdf.page(2).attributes[:Annots].size.should == 1
+      expect(pdf.page(1).attributes[:Annots]).to be_nil
+      expect(pdf.page(2).attributes[:Annots].size).to eq(1)
     end
   end
 
   it "should force :Type to be :Annot" do
-    opts = @pdf.annotate(:Rect => [0,0,10,10], :Subtype => :Text, :Contents => "Hello world!")
-    opts[:Type].should == :Annot
-    opts = @pdf.annotate(:Type => :Bogus, :Rect => [0,0,10,10], :Subtype => :Text, :Contents => "Hello world!")
-    opts[:Type].should == :Annot
+    opts = @pdf.annotate(:Rect => [0, 0, 10, 10], :Subtype => :Text, :Contents => "Hello world!")
+    expect(opts[:Type]).to eq(:Annot)
+    opts = @pdf.annotate(:Type => :Bogus, :Rect => [0, 0, 10, 10], :Subtype => :Text, :Contents => "Hello world!")
+    expect(opts[:Type]).to eq(:Annot)
   end
-
 end
 
 describe "When creating text annotations" do
-
   before(:each) do
-    @rect = [0,0,10,10]
+    @rect = [0, 0, 10, 10]
     @content = "Hello, world!"
     create_pdf
   end
 
   it "should build appropriate annotation" do
     opts = @pdf.text_annotation(@rect, @content)
-    opts[:Type].should == :Annot
-    opts[:Subtype].should == :Text
-    opts[:Rect].should == @rect
-    opts[:Contents].should == @content
+    expect(opts[:Type]).to eq(:Annot)
+    expect(opts[:Subtype]).to eq(:Text)
+    expect(opts[:Rect]).to eq(@rect)
+    expect(opts[:Contents]).to eq(@content)
   end
 
   it "should merge extra options" do
     opts = @pdf.text_annotation(@rect, @content, :Open => true, :Subtype => :Bogus)
-    opts[:Subtype].should == :Text
-    opts[:Open].should == true
+    expect(opts[:Subtype]).to eq(:Text)
+    expect(opts[:Open]).to eq(true)
   end
-
 end
 
 describe "When creating link annotations" do
-
   before(:each) do
-    @rect = [0,0,10,10]
+    @rect = [0, 0, 10, 10]
     @dest = "home"
     create_pdf
   end
 
   it "should build appropriate annotation" do
     opts = @pdf.link_annotation(@rect, :Dest => @dest)
-    opts[:Type].should == :Annot
-    opts[:Subtype].should == :Link
-    opts[:Rect].should == @rect
-    opts[:Dest].should == @dest
+    expect(opts[:Type]).to eq(:Annot)
+    expect(opts[:Subtype]).to eq(:Link)
+    expect(opts[:Rect]).to eq(@rect)
+    expect(opts[:Dest]).to eq(@dest)
   end
 
   it "should merge extra options" do
     opts = @pdf.link_annotation(@rect, :Dest => @dest, :Subtype => :Bogus)
-    opts[:Subtype].should == :Link
-    opts[:Dest].should == @dest
+    expect(opts[:Subtype]).to eq(:Link)
+    expect(opts[:Dest]).to eq(@dest)
   end
-
 end
