@@ -6,30 +6,30 @@ require 'pathname'
 describe "Font metrics caching" do
   let(:document) { Prawn::Document.new }
 
-  subject { Prawn::FontMetricCache.new( document ) }
+  subject { Prawn::FontMetricCache.new(document) }
 
   it "should start with an empty cache" do
-    subject.instance_variable_get( :@cache ).should be_empty
+    expect(subject.instance_variable_get(:@cache)).to be_empty
   end
 
   it "should cache the width of the provided string" do
     subject.width_of('M', {})
 
-    subject.instance_variable_get( :@cache ).should have(1).entry
+    expect(subject.instance_variable_get(:@cache).size).to eq(1)
   end
 
   it "should only cache a single copy of the same string" do
     subject.width_of('M', {})
     subject.width_of('M', {})
 
-    subject.instance_variable_get( :@cache ).should have(1).entry
+    expect(subject.instance_variable_get(:@cache).size).to eq(1)
   end
 
   it "should cache different copies for different strings" do
     subject.width_of('M', {})
     subject.width_of('W', {})
 
-    subject.instance_variable_get( :@cache ).should have(2).entries
+    expect(subject.instance_variable_get(:@cache).entries.size).to eq(2)
   end
 
   it "should cache different copies of the same string with different font sizes" do
@@ -38,7 +38,7 @@ describe "Font metrics caching" do
     document.font_size 24
     subject.width_of('M', {})
 
-    subject.instance_variable_get( :@cache ).should have(2).entries
+    expect(subject.instance_variable_get(:@cache).entries.size).to eq(2)
   end
 
   it "should cache different copies of the same string with different fonts" do
@@ -47,6 +47,6 @@ describe "Font metrics caching" do
     document.font 'Courier'
     subject.width_of('M', {})
 
-    subject.instance_variable_get( :@cache ).should have(2).entries
+    expect(subject.instance_variable_get(:@cache).entries.size).to eq(2)
   end
 end
