@@ -9,25 +9,27 @@ describe "Text::Formatted::Box wrapping" do
 
   it "should not wrap between two fragments" do
     texts = [
-      {:text => "Hello "},
-      {:text => "World"},
-      {:text => "2", :styles => [:superscript]},
-      ]
+      { :text => "Hello " },
+      { :text => "World" },
+      { :text => "2", :styles => [:superscript] }
+    ]
     text_box = Prawn::Text::Formatted::Box.new(texts, :document => @pdf, :width => @pdf.width_of("Hello World"))
     text_box.render
-    text_box.text.should == "Hello\nWorld2"
+    expect(text_box.text).to eq("Hello\nWorld2")
   end
 
-  it "should not raise an Encoding::CompatibilityError when keeping a TTF and an " +
-    "AFM font together" do
+  it "should not raise an Encoding::CompatibilityError when keeping a TTF and an AFM font together" do
     file = "#{Prawn::DATADIR}/fonts/gkai00mp.ttf"
+
     @pdf.font_families["Kai"] = {
       :normal => { :file => file, :font => "Kai" }
     }
 
-    texts = [{ :text => "Hello " },
-              { :text => "再见", :font => "Kai"},
-              { :text => "World" }]
+    texts = [
+      { :text => "Hello " },
+      { :text => "再见", :font => "Kai" },
+      { :text => "World" }
+    ]
     text_box = Prawn::Text::Formatted::Box.new(texts, :document => @pdf, :width => @pdf.width_of("Hello World"))
 
     text_box.render
@@ -35,77 +37,55 @@ describe "Text::Formatted::Box wrapping" do
 
   it "should wrap between two fragments when the preceding fragment ends with white space" do
     texts = [
-      {:text => "Hello "},
-      {:text => "World "},
-      {:text => "2", :styles => [:superscript]},
-      ]
+      { :text => "Hello " },
+      { :text => "World " },
+      { :text => "2", :styles => [:superscript] }
+    ]
     text_box = Prawn::Text::Formatted::Box.new(texts, :document => @pdf, :width => @pdf.width_of("Hello World"))
     text_box.render
-    text_box.text.should == "Hello World\n2"
+    expect(text_box.text).to eq("Hello World\n2")
 
     texts = [
-      {:text => "Hello "},
-      {:text => "World\n"},
-      {:text => "2", :styles => [:superscript]},
-      ]
+      { :text => "Hello " },
+      { :text => "World\n" },
+      { :text => "2", :styles => [:superscript] }
+    ]
     text_box = Prawn::Text::Formatted::Box.new(texts, :document => @pdf, :width => @pdf.width_of("Hello World"))
     text_box.render
-    text_box.text.should == "Hello World\n2"
+    expect(text_box.text).to eq("Hello World\n2")
   end
 
   it "should wrap between two fragments when the final fragment begins with white space" do
     texts = [
-      {:text => "Hello "},
-      {:text => "World"},
-      {:text => " 2", :styles => [:superscript]},
-      ]
+      { :text => "Hello " },
+      { :text => "World" },
+      { :text => " 2", :styles => [:superscript] }
+    ]
     text_box = Prawn::Text::Formatted::Box.new(texts, :document => @pdf, :width => @pdf.width_of("Hello World"))
     text_box.render
-    text_box.text.should == "Hello World\n2"
+    expect(text_box.text).to eq("Hello World\n2")
 
     texts = [
-      {:text => "Hello "},
-      {:text => "World"},
-      {:text => "\n2", :styles => [:superscript]},
-      ]
+      { :text => "Hello " },
+      { :text => "World" },
+      { :text => "\n2", :styles => [:superscript] }
+    ]
     text_box = Prawn::Text::Formatted::Box.new(texts, :document => @pdf, :width => @pdf.width_of("Hello World"))
     text_box.render
-    text_box.text.should == "Hello World\n2"
+    expect(text_box.text).to eq("Hello World\n2")
   end
 
   it "should properly handle empty slices using default encoding" do
     texts = [{ :text => "Noua Delineatio Geographica generalis | Apostolicarum peregrinationum | S FRANCISCI XAUERII | Indiarum & Iaponiæ Apostoli", :font => 'Courier', :size => 10 }]
     text_box = Prawn::Text::Formatted::Box.new(texts, :document => @pdf, :width => @pdf.width_of("Noua Delineatio Geographica gen"))
-    lambda {
+    expect {
       text_box.render
-    }.should_not raise_error
-    text_box.text.should == "Noua Delineatio Geographica\ngeneralis | Apostolicarum\nperegrinationum | S FRANCISCI\nXAUERII | Indiarum & Iaponi\346\nApostoli"
-  end
-
-  describe "Unicode" do
-    before do
-      @reset_value = [Encoding.default_external, Encoding.default_internal]
-      Encoding.default_external = Encoding::UTF_8
-      Encoding.default_internal = Encoding::UTF_8
-    end
-
-    after do
-      Encoding.default_external = @reset_value[0]
-      Encoding.default_internal = @reset_value[1]
-    end
-
-    it "should properly handle empty slices using Unicode encoding" do
-      texts = [{ :text => "Noua Delineatio Geographica generalis | Apostolicarum peregrinationum | S FRANCISCI XAUERII | Indiarum & Iaponiæ Apostoli", :font => 'Courier', :size => 10 }]
-      text_box = Prawn::Text::Formatted::Box.new(texts, :document => @pdf, :width => @pdf.width_of("Noua Delineatio Geographica gen"))
-      lambda {
-        text_box.render
-      }.should_not raise_error
-      text_box.text.should == "Noua Delineatio Geographica\ngeneralis | Apostolicarum\nperegrinationum | S FRANCISCI\nXAUERII | Indiarum & Iaponi\346\nApostoli"
-    end
+    }.not_to raise_error
+    expect(text_box.text).to eq("Noua Delineatio Geographica\ngeneralis | Apostolicarum\nperegrinationum | S FRANCISCI\nXAUERII | Indiarum & Iaponi\346\nApostoli")
   end
 end
 
-describe "Text::Formatted::Box with :fallback_fonts option that includes" +
+describe "Text::Formatted::Box with :fallback_fonts option that includes" \
   "a Chinese font and set of Chinese glyphs not in the current font" do
   it "should change the font to the Chinese font for the Chinese glyphs" do
     create_pdf
@@ -120,20 +100,20 @@ describe "Text::Formatted::Box with :fallback_fonts option that includes" +
     text = PDF::Inspector::Text.analyze(@pdf.render)
 
     fonts_used = text.font_settings.map { |e| e[:name] }
-    fonts_used.length.should == 4
-    fonts_used[0].should == :"Helvetica"
-    fonts_used[1].to_s.should =~ /GBZenKai-Medium/
-    fonts_used[2].to_s.should =~ /GBZenKai-Medium/
-    fonts_used[3].should == :"Helvetica"
+    expect(fonts_used.length).to eq(4)
+    expect(fonts_used[0]).to eq(:Helvetica)
+    expect(fonts_used[1].to_s).to match(/GBZenKai-Medium/)
+    expect(fonts_used[2].to_s).to match(/GBZenKai-Medium/)
+    expect(fonts_used[3]).to eq(:Helvetica)
 
-    text.strings[0].should == "hello"
-    text.strings[1].should == "你好"
-    text.strings[2].should == "再见"
-    text.strings[3].should == "goodbye"
+    expect(text.strings[0]).to eq("hello")
+    expect(text.strings[1]).to eq("你好")
+    expect(text.strings[2]).to eq("再见")
+    expect(text.strings[3]).to eq("goodbye")
   end
 end
 
-describe "Text::Formatted::Box with :fallback_fonts option that includes" +
+describe "Text::Formatted::Box with :fallback_fonts option that includes" \
   "an AFM font and Win-Ansi glyph not in the current Chinese font" do
   it "should change the font to the AFM font for the Win-Ansi glyph" do
     create_pdf
@@ -149,20 +129,20 @@ describe "Text::Formatted::Box with :fallback_fonts option that includes" +
     text = PDF::Inspector::Text.analyze(@pdf.render)
 
     fonts_used = text.font_settings.map { |e| e[:name] }
-    fonts_used.length.should == 4
-    fonts_used[0].to_s.should =~ /GBZenKai-Medium/
-    fonts_used[1].to_s.should =~ /GBZenKai-Medium/
-    fonts_used[2].to_s.should =~ /GBZenKai-Medium/
-    fonts_used[3].should == :"Helvetica"
+    expect(fonts_used.length).to eq(4)
+    expect(fonts_used[0].to_s).to match(/GBZenKai-Medium/)
+    expect(fonts_used[1].to_s).to match(/GBZenKai-Medium/)
+    expect(fonts_used[2].to_s).to match(/GBZenKai-Medium/)
+    expect(fonts_used[3]).to eq(:Helvetica)
 
-    text.strings[0].should == "hello"
-    text.strings[1].should == "你好"
-    text.strings[2].should == "再见"
-    text.strings[3].should == "€"
+    expect(text.strings[0]).to eq("hello")
+    expect(text.strings[1]).to eq("你好")
+    expect(text.strings[2]).to eq("再见")
+    expect(text.strings[3]).to eq("€")
   end
 end
 
-describe "Text::Formatted::Box with :fallback_fonts option and fragment " +
+describe "Text::Formatted::Box with :fallback_fonts option and fragment " \
   "level font" do
   it "should use the fragment level font except for glyphs not in that font" do
     create_pdf
@@ -170,6 +150,12 @@ describe "Text::Formatted::Box with :fallback_fonts option and fragment " +
     @pdf.font_families["Kai"] = {
       :normal => { :file => file, :font => "Kai" }
     }
+
+    file = "#{Prawn::DATADIR}/fonts/DejaVuSans.ttf"
+    @pdf.font_families["DejaVu Sans"] = {
+      :normal => { :file => file }
+    }
+
     formatted_text = [{ :text => "hello你好" },
                       { :text => "再见goodbye", :font => "Times-Roman" }]
     @pdf.formatted_text_box(formatted_text, :fallback_fonts => ["Kai"])
@@ -177,16 +163,16 @@ describe "Text::Formatted::Box with :fallback_fonts option and fragment " +
     text = PDF::Inspector::Text.analyze(@pdf.render)
 
     fonts_used = text.font_settings.map { |e| e[:name] }
-    fonts_used.length.should == 4
-    fonts_used[0].should == :"Helvetica"
-    fonts_used[1].to_s.should =~ /GBZenKai-Medium/
-    fonts_used[2].to_s.should =~ /GBZenKai-Medium/
-    fonts_used[3].should == :"Times-Roman"
+    expect(fonts_used.length).to eq(4)
+    expect(fonts_used[0]).to eq(:Helvetica)
+    expect(fonts_used[1].to_s).to match(/GBZenKai-Medium/)
+    expect(fonts_used[2].to_s).to match(/GBZenKai-Medium/)
+    expect(fonts_used[3]).to eq(:"Times-Roman")
 
-    text.strings[0].should == "hello"
-    text.strings[1].should == "你好"
-    text.strings[2].should == "再见"
-    text.strings[3].should == "goodbye"
+    expect(text.strings[0]).to eq("hello")
+    expect(text.strings[1]).to eq("你好")
+    expect(text.strings[2]).to eq("再见")
+    expect(text.strings[3]).to eq("goodbye")
   end
 end
 
@@ -197,12 +183,18 @@ describe "Text::Formatted::Box" do
     @pdf.font_families["Kai"] = {
       :normal => { :file => file, :font => "Kai" }
     }
+
+    file = "#{Prawn::DATADIR}/fonts/DejaVuSans.ttf"
+    @pdf.font_families["DejaVu Sans"] = {
+      :normal => { :file => file }
+    }
+
     @formatted_text = [{ :text => "hello你好" }]
     @pdf.fallback_fonts(["Kai"])
     @pdf.fallback_fonts = ["Kai"]
   end
   it "#fallback_fonts should return the document-wide fallback fonts" do
-    @pdf.fallback_fonts.should == ["Kai"]
+    expect(@pdf.fallback_fonts).to eq(["Kai"])
   end
   it "should be able to set text fallback_fonts document-wide" do
     @pdf.formatted_text_box(@formatted_text)
@@ -210,48 +202,55 @@ describe "Text::Formatted::Box" do
     text = PDF::Inspector::Text.analyze(@pdf.render)
 
     fonts_used = text.font_settings.map { |e| e[:name] }
-    fonts_used.length.should == 2
-    fonts_used[0].should == :"Helvetica"
-    fonts_used[1].to_s.should =~ /GBZenKai-Medium/
+    expect(fonts_used.length).to eq(2)
+    expect(fonts_used[0]).to eq(:Helvetica)
+    expect(fonts_used[1].to_s).to match(/GBZenKai-Medium/)
   end
   it "should be able to override document-wide fallback_fonts" do
-    @pdf.formatted_text_box(@formatted_text, :fallback_fonts => ["Courier"])
+    @pdf.fallback_fonts = ["DejaVu Sans"]
+    @pdf.formatted_text_box(@formatted_text, :fallback_fonts => ["Kai"])
 
     text = PDF::Inspector::Text.analyze(@pdf.render)
 
     fonts_used = text.font_settings.map { |e| e[:name] }
-    fonts_used.length.should == 1
-    fonts_used[0].should == :"Helvetica"
+    expect(fonts_used.length).to eq(2)
+    expect(fonts_used[0]).to eq(:Helvetica)
+    expect(fonts_used[1]).to match(/Kai/)
   end
-  it "should omit the fallback fonts overhead when passing an empty array " +
+  it "should omit the fallback fonts overhead when passing an empty array " \
     "as the :fallback_fonts" do
+    @pdf.font("Kai")
+
     box = Prawn::Text::Formatted::Box.new(@formatted_text,
                                           :document => @pdf,
                                           :fallback_fonts => [])
+
     box.expects(:process_fallback_fonts).never
     box.render
   end
+
   it "should be able to clear document-wide fallback_fonts" do
     @pdf.fallback_fonts([])
     box = Prawn::Text::Formatted::Box.new(@formatted_text,
                                           :document => @pdf)
+
+    @pdf.font("Kai")
+
     box.expects(:process_fallback_fonts).never
     box.render
   end
 end
 
-describe "Text::Formatted::Box with :fallback_fonts option " +
+describe "Text::Formatted::Box with :fallback_fonts option " \
   "with glyphs not in the primary or the fallback fonts" do
-  it "should use the primary font" do
+  it "should raise an exception" do
+    file = "#{Prawn::DATADIR}/fonts/gkai00mp.ttf"
     create_pdf
     formatted_text = [{ :text => "hello world. 世界你好。" }]
-    @pdf.formatted_text_box(formatted_text, :fallback_fonts => ["Helvetica"])
 
-    text = PDF::Inspector::Text.analyze(@pdf.render)
-
-    fonts_used = text.font_settings.map { |e| e[:name] }
-    fonts_used.length.should == 1
-    fonts_used[0].should == :"Helvetica"
+    expect {
+      @pdf.formatted_text_box(formatted_text, :fallback_fonts => ["Courier"])
+    }.to raise_error(Prawn::Errors::IncompatibleStringEncoding)
   end
 end
 
@@ -262,16 +261,16 @@ describe "Text::Formatted::Box#extensions" do
     @pdf.formatted_text_box([{ :text => "hello world" }], {})
     Prawn::Text::Formatted::Box.extensions.delete(TestFormattedWrapOverride)
     text = PDF::Inspector::Text.analyze(@pdf.render)
-    text.strings[0].should == "all your base are belong to us"
+    expect(text.strings[0]).to eq("all your base are belong to us")
   end
-  it "overriding Text::Formatted::Box line wrapping should not affect " +
+  it "overriding Text::Formatted::Box line wrapping should not affect " \
      "Text::Box wrapping" do
     create_pdf
     Prawn::Text::Formatted::Box.extensions << TestFormattedWrapOverride
     @pdf.text_box("hello world", {})
     Prawn::Text::Formatted::Box.extensions.delete(TestFormattedWrapOverride)
     text = PDF::Inspector::Text.analyze(@pdf.render)
-    text.strings[0].should == "hello world"
+    expect(text.strings[0]).to eq("hello world")
   end
   it "overriding Text::Box line wrapping should override Text::Box wrapping" do
     create_pdf
@@ -279,73 +278,73 @@ describe "Text::Formatted::Box#extensions" do
     @pdf.text_box("hello world", {})
     Prawn::Text::Box.extensions.delete(TestFormattedWrapOverride)
     text = PDF::Inspector::Text.analyze(@pdf.render)
-    text.strings[0].should == "all your base are belong to us"
+    expect(text.strings[0]).to eq("all your base are belong to us")
   end
 end
 
 describe "Text::Formatted::Box#render" do
   it "should handle newlines" do
     create_pdf
-    array = [{ :text => "hello\nworld"}]
+    array = [{ :text => "hello\nworld" }]
     options = { :document => @pdf }
     text_box = Prawn::Text::Formatted::Box.new(array, options)
     text_box.render
-    text_box.text.should == "hello\nworld"
+    expect(text_box.text).to eq("hello\nworld")
   end
   it "should omit spaces from the beginning of the line" do
     create_pdf
-    array = [{ :text => " hello\n world"}]
+    array = [{ :text => " hello\n world" }]
     options = { :document => @pdf }
     text_box = Prawn::Text::Formatted::Box.new(array, options)
     text_box.render
-    text_box.text.should == "hello\nworld"
+    expect(text_box.text).to eq("hello\nworld")
   end
   it "should be okay printing a line of whitespace" do
     create_pdf
-    array = [{ :text => "hello\n    \nworld"}]
+    array = [{ :text => "hello\n    \nworld" }]
     options = { :document => @pdf }
     text_box = Prawn::Text::Formatted::Box.new(array, options)
     text_box.render
-    text_box.text.should == "hello\n\nworld"
+    expect(text_box.text).to eq("hello\n\nworld")
 
-
-    array = [{ :text => "hello" + " " * 500},
+    array = [{ :text => "hello" + " " * 500 },
              { :text => " " * 500 },
-             { :text => " " * 500 + "\n"},
-             { :text => "world"}]
+             { :text => " " * 500 + "\n" },
+             { :text => "world" }]
     options = { :document => @pdf }
     text_box = Prawn::Text::Formatted::Box.new(array, options)
     text_box.render
-    text_box.text.should == "hello\n\nworld"
+    expect(text_box.text).to eq("hello\n\nworld")
   end
   it "should enable fragment level direction setting" do
     create_pdf
     number_of_hellos = 18
     array = [
-             { :text => "hello " * number_of_hellos },
-             { :text => "world", :direction => :ltr },
-             { :text => ", how are you?" }
-            ]
+      { :text => "hello " * number_of_hellos },
+      { :text => "world", :direction => :ltr },
+      { :text => ", how are you?" }
+    ]
     options = { :document => @pdf, :direction => :rtl }
     text_box = Prawn::Text::Formatted::Box.new(array, options)
     text_box.render
     text = PDF::Inspector::Text.analyze(@pdf.render)
-    text.strings[0].should == "era woh ,"
-    text.strings[1].should == "world"
-    text.strings[2].should == " olleh" * number_of_hellos
-    text.strings[3].should == "?uoy"
+    expect(text.strings[0]).to eq("era woh ,")
+    expect(text.strings[1]).to eq("world")
+    expect(text.strings[2]).to eq(" olleh" * number_of_hellos)
+    expect(text.strings[3]).to eq("?uoy")
   end
 end
 
 describe "Text::Formatted::Box#render" do
   it "should be able to perform fragment callbacks" do
     create_pdf
-    callback_object = TestFragmentCallback.new("something", 7,
-                                               :document => @pdf)
+    callback_object = TestFragmentCallback.new("something", 7, :document => @pdf)
     callback_object.expects(:render_behind).with(
-                                      kind_of(Prawn::Text::Formatted::Fragment))
+      kind_of(Prawn::Text::Formatted::Fragment)
+    )
     callback_object.expects(:render_in_front).with(
-                                      kind_of(Prawn::Text::Formatted::Fragment))
+      kind_of(Prawn::Text::Formatted::Fragment)
+    )
     array = [{ :text => "hello world " },
              { :text => "callback now",
                :callback => callback_object }]
@@ -355,19 +354,21 @@ describe "Text::Formatted::Box#render" do
   it "should be able to perform fragment callbacks on multiple objects" do
     create_pdf
 
-    callback_object = TestFragmentCallback.new("something", 7,
-                                               :document => @pdf)
+    callback_object = TestFragmentCallback.new("something", 7, :document => @pdf)
     callback_object.expects(:render_behind).with(
-                                      kind_of(Prawn::Text::Formatted::Fragment))
+      kind_of(Prawn::Text::Formatted::Fragment)
+    )
     callback_object.expects(:render_in_front).with(
-                                      kind_of(Prawn::Text::Formatted::Fragment))
+      kind_of(Prawn::Text::Formatted::Fragment)
+    )
 
-    callback_object2 = TestFragmentCallback.new("something else", 14,
-                                               :document => @pdf)
+    callback_object2 = TestFragmentCallback.new("something else", 14, :document => @pdf)
     callback_object2.expects(:render_behind).with(
-                                      kind_of(Prawn::Text::Formatted::Fragment))
+      kind_of(Prawn::Text::Formatted::Fragment)
+    )
     callback_object2.expects(:render_in_front).with(
-                                      kind_of(Prawn::Text::Formatted::Fragment))
+      kind_of(Prawn::Text::Formatted::Fragment)
+    )
 
     array = [{ :text => "hello world " },
              { :text => "callback now",
@@ -399,10 +400,10 @@ describe "Text::Formatted::Box#render" do
     text_box.render
     contents = PDF::Inspector::Text.analyze(@pdf.render)
     fonts = contents.font_settings.map { |e| e[:name] }
-    fonts.should == [:Helvetica, :"Times-Bold", :Helvetica]
-    contents.strings[0].should == "this contains "
-    contents.strings[1].should == "Times-Bold"
-    contents.strings[2].should == " text"
+    expect(fonts).to eq([:Helvetica, :"Times-Bold", :Helvetica])
+    expect(contents.strings[0]).to eq("this contains ")
+    expect(contents.strings[1]).to eq("Times-Bold")
+    expect(contents.strings[2]).to eq(" text")
   end
   it "should be able to set bold" do
     create_pdf
@@ -413,10 +414,10 @@ describe "Text::Formatted::Box#render" do
     text_box.render
     contents = PDF::Inspector::Text.analyze(@pdf.render)
     fonts = contents.font_settings.map { |e| e[:name] }
-    fonts.should == [:Helvetica, :"Helvetica-Bold", :Helvetica]
-    contents.strings[0].should == "this contains "
-    contents.strings[1].should == "bold"
-    contents.strings[2].should == " text"
+    expect(fonts).to eq([:Helvetica, :"Helvetica-Bold", :Helvetica])
+    expect(contents.strings[0]).to eq("this contains ")
+    expect(contents.strings[1]).to eq("bold")
+    expect(contents.strings[2]).to eq(" text")
   end
   it "should be able to set italics" do
     create_pdf
@@ -427,7 +428,7 @@ describe "Text::Formatted::Box#render" do
     text_box.render
     contents = PDF::Inspector::Text.analyze(@pdf.render)
     fonts = contents.font_settings.map { |e| e[:name] }
-    fonts.should == [:Helvetica, :"Helvetica-Oblique", :Helvetica]
+    expect(fonts).to eq([:Helvetica, :"Helvetica-Oblique", :Helvetica])
   end
   it "should be able to set subscript" do
     create_pdf
@@ -437,8 +438,8 @@ describe "Text::Formatted::Box#render" do
     text_box = Prawn::Text::Formatted::Box.new(array, :document => @pdf)
     text_box.render
     contents = PDF::Inspector::Text.analyze(@pdf.render)
-    contents.font_settings[0][:size].should == 12
-    contents.font_settings[1][:size].should be_within(0.0001).of(18 * 0.583)
+    expect(contents.font_settings[0][:size]).to eq(12)
+    expect(contents.font_settings[1][:size]).to be_within(0.0001).of(18 * 0.583)
   end
   it "should be able to set superscript" do
     create_pdf
@@ -448,8 +449,8 @@ describe "Text::Formatted::Box#render" do
     text_box = Prawn::Text::Formatted::Box.new(array, :document => @pdf)
     text_box.render
     contents = PDF::Inspector::Text.analyze(@pdf.render)
-    contents.font_settings[0][:size].should == 12
-    contents.font_settings[1][:size].should be_within(0.0001).of(18 * 0.583)
+    expect(contents.font_settings[0][:size]).to eq(12)
+    expect(contents.font_settings[1][:size]).to be_within(0.0001).of(18 * 0.583)
   end
   it "should be able to set compound bold and italic text" do
     create_pdf
@@ -460,7 +461,7 @@ describe "Text::Formatted::Box#render" do
     text_box.render
     contents = PDF::Inspector::Text.analyze(@pdf.render)
     fonts = contents.font_settings.map { |e| e[:name] }
-    fonts.should == [:Helvetica, :"Helvetica-BoldOblique", :Helvetica]
+    expect(fonts).to eq([:Helvetica, :"Helvetica-BoldOblique", :Helvetica])
   end
   it "should be able to underline" do
     create_pdf
@@ -470,7 +471,7 @@ describe "Text::Formatted::Box#render" do
     text_box = Prawn::Text::Formatted::Box.new(array, :document => @pdf)
     text_box.render
     line_drawing = PDF::Inspector::Graphics::Line.analyze(@pdf.render)
-    line_drawing.points.length.should == 2
+    expect(line_drawing.points.length).to eq(2)
   end
   it "should be able to strikethrough" do
     create_pdf
@@ -480,12 +481,16 @@ describe "Text::Formatted::Box#render" do
     text_box = Prawn::Text::Formatted::Box.new(array, :document => @pdf)
     text_box.render
     line_drawing = PDF::Inspector::Graphics::Line.analyze(@pdf.render)
-    line_drawing.points.length.should == 2
+    expect(line_drawing.points.length).to eq(2)
   end
   it "should be able to add URL links" do
     create_pdf
-    @pdf.expects(:link_annotation).with(kind_of(Array), :Border => [0,0,0],
-           :A => { :Type => :Action, :S => :URI, :URI => "http://example.com" })
+    @pdf.expects(:link_annotation).with(kind_of(Array), :Border => [0, 0, 0],
+                                                        :A => {
+                                                          :Type => :Action,
+                                                          :S => :URI,
+                                                          :URI => "http://example.com"
+                                                        })
     array = [{ :text => "click " },
              { :text => "here", :link => "http://example.com" },
              { :text => " to visit" }]
@@ -494,8 +499,8 @@ describe "Text::Formatted::Box#render" do
   end
   it "should be able to add destination links" do
     create_pdf
-    @pdf.expects(:link_annotation).with(kind_of(Array), :Border => [0,0,0],
-                                        :Dest => "ToC")
+    @pdf.expects(:link_annotation).with(kind_of(Array), :Border => [0, 0, 0],
+                                                        :Dest => "ToC")
     array = [{ :text => "Go to the " },
              { :text => "Table of Contents", :anchor => "ToC" }]
     text_box = Prawn::Text::Formatted::Box.new(array, :document => @pdf)
@@ -503,8 +508,13 @@ describe "Text::Formatted::Box#render" do
   end
   it "should be able to add local actions" do
     create_pdf
-    @pdf.expects(:link_annotation).with(kind_of(Array), :Border => [0,0,0],
-           :A => { :Type => :Action, :S => :Launch, :F => "../example.pdf", :NewWindow => true })
+    @pdf.expects(:link_annotation).with(kind_of(Array), :Border => [0, 0, 0],
+                                                        :A => {
+                                                          :Type => :Action,
+                                                          :S => :Launch,
+                                                          :F => "../example.pdf",
+                                                          :NewWindow => true
+                                                        })
     array = [{ :text => "click " },
              { :text => "here", :local => "../example.pdf" },
              { :text => " to open a local file" }]
@@ -519,8 +529,8 @@ describe "Text::Formatted::Box#render" do
     text_box = Prawn::Text::Formatted::Box.new(array, :document => @pdf)
     text_box.render
     contents = PDF::Inspector::Text.analyze(@pdf.render)
-    contents.font_settings[0][:size].should == 12
-    contents.font_settings[1][:size].should == 24
+    expect(contents.font_settings[0][:size]).to eq(12)
+    expect(contents.font_settings[1][:size]).to eq(24)
   end
   it "should set the baseline based on the tallest fragment on a given line" do
     create_pdf
@@ -530,7 +540,7 @@ describe "Text::Formatted::Box#render" do
     text_box = Prawn::Text::Formatted::Box.new(array, :document => @pdf)
     text_box.render
     @pdf.font_size(24) do
-      text_box.height.should be_within(0.001).of(@pdf.font.ascender + @pdf.font.descender)
+      expect(text_box.height).to be_within(0.001).of(@pdf.font.ascender + @pdf.font.descender)
     end
   end
   it "should be able to set color via an rgb hex string" do
@@ -540,8 +550,8 @@ describe "Text::Formatted::Box#render" do
     text_box = Prawn::Text::Formatted::Box.new(array, :document => @pdf)
     text_box.render
     colors = PDF::Inspector::Graphics::Color.analyze(@pdf.render)
-    colors.fill_color_count.should == 2
-    colors.stroke_color_count.should == 2
+    expect(colors.fill_color_count).to eq(2)
+    expect(colors.stroke_color_count).to eq(2)
   end
   it "should be able to set color using a cmyk array" do
     create_pdf
@@ -550,8 +560,8 @@ describe "Text::Formatted::Box#render" do
     text_box = Prawn::Text::Formatted::Box.new(array, :document => @pdf)
     text_box.render
     colors = PDF::Inspector::Graphics::Color.analyze(@pdf.render)
-    colors.fill_color_count.should == 2
-    colors.stroke_color_count.should == 2
+    expect(colors.fill_color_count).to eq(2)
+    expect(colors.stroke_color_count).to eq(2)
   end
 end
 
@@ -571,9 +581,9 @@ describe "Text::Formatted::Box#render(:dry_run => true)" do
     text_box.render(:dry_run => true)
 
     state_after = PDF::Inspector::Graphics::Color.analyze(@pdf.render)
-    state_after.fill_color_count.should == fill_color_count
-    state_after.stroke_color_count.should == stroke_color_count
-    state_after.stroke_color_space_count.should == stroke_color_space_count
+    expect(state_after.fill_color_count).to eq(fill_color_count)
+    expect(state_after.stroke_color_count).to eq(stroke_color_count)
+    expect(state_after.stroke_color_space_count).to eq(stroke_color_space_count)
   end
 end
 
@@ -586,7 +596,7 @@ describe "Text::Formatted::Box#render with fragment level :character_spacing opt
     text_box = Prawn::Text::Formatted::Box.new(array, options)
     text_box.render
     contents = PDF::Inspector::Text.analyze(@pdf.render)
-    contents.character_spacing[0].should == 7
+    expect(contents.character_spacing[0]).to eq(7)
   end
   it "should draw the character spacing to the document" do
     create_pdf
@@ -598,7 +608,7 @@ describe "Text::Formatted::Box#render with fragment level :character_spacing opt
                 :overflow => :expand }
     text_box = Prawn::Text::Formatted::Box.new(array, options)
     text_box.render
-    text_box.text.should == "hello\nworld"
+    expect(text_box.text).to eq("hello\nworld")
   end
 end
 
@@ -612,7 +622,52 @@ describe "Text::Formatted::Box#render with :align => :justify" do
     text_box = Prawn::Text::Formatted::Box.new(array, options)
     text_box.render
     contents = PDF::Inspector::Text.analyze(@pdf.render)
-    contents.word_spacing.should be_empty
+    expect(contents.word_spacing).to be_empty
+  end
+end
+
+describe "Text::Formatted::Box#render with :valign => :center" do
+  it "should have a bottom gap equal to baseline and bottom of box" do
+    create_pdf
+    box_height = 100
+    y = 450
+    array = [{ :text => 'Vertical Align' }]
+    options = {
+      :document => @pdf,
+      :valign => :center,
+      :at => [0, y],
+      :width => 100,
+      :height => box_height,
+      :size => 16
+    }
+    text_box = Prawn::Text::Formatted::Box.new(array, options)
+    text_box.render
+    line_padding = (box_height - text_box.height + text_box.descender) * 0.5
+    baseline = y - line_padding
+
+    expect(text_box.at[1]).to be_within(0.01).of(baseline)
+  end
+end
+
+describe "Text::Formatted::Box#render with :valign => :bottom" do
+  it "should not render a gap between the text and bottom of box" do
+    create_pdf
+    box_height = 100
+    y = 450
+    array = [{ :text => 'Vertical Align' }]
+    options = {
+      :document => @pdf,
+      :valign => :bottom,
+      :at => [0, y],
+      :width => 100,
+      :height => box_height,
+      :size => 16
+    }
+    text_box = Prawn::Text::Formatted::Box.new(array, options)
+    text_box.render
+    top_padding = y - (box_height - text_box.height)
+
+    expect(text_box.at[1]).to be_within(0.01).of(top_padding)
   end
 end
 
