@@ -5,20 +5,20 @@ require File.join(File.expand_path(File.dirname(__FILE__)), "spec_helper")
 describe "Text::Formatted::Fragment#space_count" do
   it "should return the number of spaces in the fragment" do
     create_pdf
-    format_state = { }
+    format_state = {}
     fragment = Prawn::Text::Formatted::Fragment.new("hello world ",
-                                                     format_state,
-                                                     @pdf)
-    fragment.space_count.should == 2
+                                                    format_state,
+                                                    @pdf)
+    expect(fragment.space_count).to eq(2)
   end
-  it "should exclude trailing spaces from the count when " +
+  it "should exclude trailing spaces from the count when " \
     ":exclude_trailing_white_space => true" do
     create_pdf
     format_state = { :exclude_trailing_white_space => true }
     fragment = Prawn::Text::Formatted::Fragment.new("hello world ",
-                                                     format_state,
-                                                     @pdf)
-    fragment.space_count.should == 1
+                                                    format_state,
+                                                    @pdf)
+    expect(fragment.space_count).to eq(1)
   end
 end
 
@@ -27,31 +27,31 @@ describe "Text::Formatted::Fragment#include_trailing_white_space!" do
     create_pdf
     format_state = { :exclude_trailing_white_space => true }
     fragment = Prawn::Text::Formatted::Fragment.new("hello world ",
-                                                     format_state,
-                                                     @pdf)
-    fragment.space_count.should == 1
+                                                    format_state,
+                                                    @pdf)
+    expect(fragment.space_count).to eq(1)
     fragment.include_trailing_white_space!
-    fragment.space_count.should == 2
+    expect(fragment.space_count).to eq(2)
   end
 end
 
 describe "Text::Formatted::Fragment#text" do
   it "should return the fragment text" do
     create_pdf
-    format_state = { }
+    format_state = {}
     fragment = Prawn::Text::Formatted::Fragment.new("hello world ",
-                                                     format_state,
-                                                     @pdf)
-    fragment.text.should == "hello world "
+                                                    format_state,
+                                                    @pdf)
+    expect(fragment.text).to eq("hello world ")
   end
-  it "should return the fragment text without trailing spaces when " +
+  it "should return the fragment text without trailing spaces when " \
     ":exclude_trailing_white_space => true" do
     create_pdf
     format_state = { :exclude_trailing_white_space => true }
     fragment = Prawn::Text::Formatted::Fragment.new("hello world ",
-                                                     format_state,
-                                                     @pdf)
-    fragment.text.should == "hello world"
+                                                    format_state,
+                                                    @pdf)
+    expect(fragment.text).to eq("hello world")
   end
 end
 
@@ -77,11 +77,11 @@ describe "Text::Formatted::Fragment#word_spacing=" do
   end
 
   it "should account for word_spacing in #width" do
-    @fragment.width.should == 110
+    expect(@fragment.width).to eq(110)
   end
   it "should account for word_spacing in #bounding_box" do
     target_box = [50, 193, 160, 217]
-    @fragment.bounding_box.should == target_box
+    expect(@fragment.bounding_box).to eq(target_box)
   end
   it "should account for word_spacing in #absolute_bounding_box" do
     target_box = [50, 193, 160, 217]
@@ -89,17 +89,17 @@ describe "Text::Formatted::Fragment#word_spacing=" do
     target_box[1] += @pdf.bounds.absolute_bottom
     target_box[2] += @pdf.bounds.absolute_left
     target_box[3] += @pdf.bounds.absolute_bottom
-    @fragment.absolute_bounding_box.should == target_box
+    expect(@fragment.absolute_bounding_box).to eq(target_box)
   end
   it "should account for word_spacing in #underline_points" do
     y = 198.75
     target_points = [[50, y], [160, y]]
-    @fragment.underline_points.should == target_points
+    expect(@fragment.underline_points).to eq(target_points)
   end
   it "should account for word_spacing in #strikethrough_points" do
     y = 200 + @fragment.ascender * 0.3
     target_points = [[50, y], [160, y]]
-    @fragment.strikethrough_points.should == target_points
+    expect(@fragment.strikethrough_points).to eq(target_points)
   end
 end
 
@@ -125,13 +125,13 @@ describe "Text::Formatted::Fragment" do
 
   describe "#width" do
     it "should return the width" do
-      @fragment.width.should == 100
+      expect(@fragment.width).to eq(100)
     end
   end
 
   describe "#styles" do
     it "should return the styles array" do
-      @fragment.styles.should == [:bold, :italic]
+      expect(@fragment.styles).to eq([:bold, :italic])
     end
     it "should never return nil" do
       format_state = { :styles => nil,
@@ -143,50 +143,51 @@ describe "Text::Formatted::Fragment" do
       fragment = Prawn::Text::Formatted::Fragment.new("hello world",
                                                       format_state,
                                                       @pdf)
-      fragment.styles.should == []
+      expect(fragment.styles).to eq([])
     end
   end
 
   describe "#line_height" do
     it "should return the line_height" do
-      @fragment.line_height.should == 27
+      expect(@fragment.line_height).to eq(27)
     end
   end
 
   describe "#ascender" do
     it "should return the ascender" do
-      @fragment.ascender.should == 17
+      expect(@fragment.ascender).to eq(17)
     end
   end
 
   describe "#descender" do
     it "should return the descender" do
-      @fragment.descender.should == 7
+      expect(@fragment.descender).to eq(7)
     end
   end
 
   describe "#y_offset" do
     it "should be zero" do
-      @fragment.y_offset.should == 0
+      expect(@fragment.y_offset).to eq(0)
     end
   end
 
   describe "#bounding_box" do
     it "should return the bounding box surrounding the fragment" do
       target_box = [50, 193, 150, 217]
-      @fragment.bounding_box.should == target_box
+      expect(@fragment.bounding_box).to eq(target_box)
     end
   end
 
   describe "#absolute_bounding_box" do
-    it "should return the bounding box surrounding the fragment" +
+    it "should return the bounding box surrounding the fragment" \
        " in absolute coordinates" do
       target_box = [50, 193, 150, 217]
-        target_box[0] += @pdf.bounds.absolute_left
-        target_box[1] += @pdf.bounds.absolute_bottom
-        target_box[2] += @pdf.bounds.absolute_left
-        target_box[3] += @pdf.bounds.absolute_bottom
-      @fragment.absolute_bounding_box.should == target_box
+      target_box[0] += @pdf.bounds.absolute_left
+      target_box[1] += @pdf.bounds.absolute_bottom
+      target_box[2] += @pdf.bounds.absolute_left
+      target_box[3] += @pdf.bounds.absolute_bottom
+
+      expect(@fragment.absolute_bounding_box).to eq(target_box)
     end
   end
 
@@ -194,7 +195,7 @@ describe "Text::Formatted::Fragment" do
     it "should define a line under the fragment" do
       y = 198.75
       target_points = [[50, y], [150, y]]
-      @fragment.underline_points.should == target_points
+      expect(@fragment.underline_points).to eq(target_points)
     end
   end
 
@@ -202,7 +203,7 @@ describe "Text::Formatted::Fragment" do
     it "should define a line through the fragment" do
       y = 200 + @fragment.ascender * 0.3
       target_points = [[50, y], [150, y]]
-      @fragment.strikethrough_points.should == target_points
+      expect(@fragment.strikethrough_points).to eq(target_points)
     end
   end
 end
@@ -225,12 +226,12 @@ describe "Text::Formatted::Fragment that is a subscript" do
   end
   describe "#subscript?" do
     it "should be_true" do
-      @fragment.should be_subscript
+      expect(@fragment).to be_subscript
     end
   end
   describe "#y_offset" do
     it "should return a negative value" do
-      @fragment.y_offset.should be < 0
+      expect(@fragment.y_offset).to be < 0
     end
   end
 end
@@ -253,12 +254,12 @@ describe "Text::Formatted::Fragment that is a superscript" do
   end
   describe "#superscript?" do
     it "should be_true" do
-      @fragment.should be_superscript
+      expect(@fragment).to be_superscript
     end
   end
   describe "#y_offset" do
     it "should return a positive value" do
-      @fragment.y_offset.should be > 0
+      expect(@fragment.y_offset).to be > 0
     end
   end
 end
@@ -268,31 +269,31 @@ describe "Text::Formatted::Fragment with :direction => :rtl" do
     create_pdf
     format_state = { :direction => :rtl }
     fragment = Prawn::Text::Formatted::Fragment.new("hello world",
-                                                     format_state,
-                                                     @pdf)
-    fragment.text.should == "dlrow olleh"
+                                                    format_state,
+                                                    @pdf)
+    expect(fragment.text).to eq("dlrow olleh")
   end
 end
 
 describe "Text::Formatted::Fragment default_direction=" do
-  it "should set the direction if there is no fragment level direction " +
+  it "should set the direction if there is no fragment level direction " \
      "specification" do
     create_pdf
-    format_state = { }
+    format_state = {}
     fragment = Prawn::Text::Formatted::Fragment.new("hello world",
-                                                     format_state,
-                                                     @pdf)
+                                                    format_state,
+                                                    @pdf)
     fragment.default_direction = :rtl
-    fragment.direction.should == :rtl
+    expect(fragment.direction).to eq(:rtl)
   end
-  it "should not set the direction if there is a fragment level direction " +
+  it "should not set the direction if there is a fragment level direction " \
      "specification" do
     create_pdf
     format_state = { :direction => :rtl }
     fragment = Prawn::Text::Formatted::Fragment.new("hello world",
-                                                     format_state,
+                                                    format_state,
                                                     @pdf)
     fragment.default_direction = :ltr
-    fragment.direction.should == :rtl
+    expect(fragment.direction).to eq(:rtl)
   end
 end
