@@ -10,7 +10,6 @@
 require File.join(File.expand_path(File.dirname(__FILE__)), "spec_helper")
 
 describe "When reading a greyscale PNG file (color type 0)" do
-
   before(:each) do
     @filename = "#{Prawn::DATADIR}/images/web-links.png"
     @data_filename = "#{Prawn::DATADIR}/images/web-links.dat"
@@ -20,24 +19,23 @@ describe "When reading a greyscale PNG file (color type 0)" do
   it "should read the attributes from the header chunk correctly" do
     png = Prawn::Images::PNG.new(@img_data)
 
-    png.width.should == 21
-    png.height.should == 14
-    png.bits.should == 8
-    png.color_type.should == 0
-    png.compression_method.should == 0
-    png.filter_method.should == 0
-    png.interlace_method.should == 0
+    expect(png.width).to eq(21)
+    expect(png.height).to eq(14)
+    expect(png.bits).to eq(8)
+    expect(png.color_type).to eq(0)
+    expect(png.compression_method).to eq(0)
+    expect(png.filter_method).to eq(0)
+    expect(png.interlace_method).to eq(0)
   end
 
   it "should read the image data chunk correctly" do
     png = Prawn::Images::PNG.new(@img_data)
     data = Zlib::Inflate.inflate(File.binread(@data_filename))
-    png.img_data.should == data
+    expect(png.img_data).to eq(data)
   end
 end
 
 describe "When reading a greyscale PNG file with transparency (color type 0)" do
-
   before(:each) do
     @filename = "#{Prawn::DATADIR}/images/ruport_type0.png"
     @img_data = File.binread(@filename)
@@ -49,12 +47,11 @@ describe "When reading a greyscale PNG file with transparency (color type 0)" do
   # http://www.w3.org/TR/PNG/#11tRNS
   it "should read the tRNS chunk correctly" do
     png = Prawn::Images::PNG.new(@img_data)
-    png.transparency[:grayscale].should == 255
+    expect(png.transparency[:grayscale]).to eq(255)
   end
 end
 
 describe "When reading an RGB PNG file (color type 2)" do
-
   before(:each) do
     @filename = "#{Prawn::DATADIR}/images/ruport.png"
     @data_filename = "#{Prawn::DATADIR}/images/ruport_data.dat"
@@ -64,24 +61,23 @@ describe "When reading an RGB PNG file (color type 2)" do
   it "should read the attributes from the header chunk correctly" do
     png = Prawn::Images::PNG.new(@img_data)
 
-    png.width.should == 258
-    png.height.should == 105
-    png.bits.should == 8
-    png.color_type.should == 2
-    png.compression_method.should == 0
-    png.filter_method.should == 0
-    png.interlace_method.should == 0
+    expect(png.width).to eq(258)
+    expect(png.height).to eq(105)
+    expect(png.bits).to eq(8)
+    expect(png.color_type).to eq(2)
+    expect(png.compression_method).to eq(0)
+    expect(png.filter_method).to eq(0)
+    expect(png.interlace_method).to eq(0)
   end
 
   it "should read the image data chunk correctly" do
     png = Prawn::Images::PNG.new(@img_data)
     data = Zlib::Inflate.inflate(File.binread(@data_filename))
-    png.img_data.should == data
+    expect(png.img_data).to eq(data)
   end
 end
 
 describe "When reading an RGB PNG file with transparency (color type 2)" do
-
   before(:each) do
     @filename = "#{Prawn::DATADIR}/images/arrow2.png"
     @img_data = File.binread(@filename)
@@ -94,14 +90,19 @@ describe "When reading an RGB PNG file with transparency (color type 2)" do
   # http://www.w3.org/TR/PNG/#11tRNS
   it "should read the tRNS chunk correctly" do
     png = Prawn::Images::PNG.new(@img_data)
-    png.transparency[:rgb].should == [0, 255, 0]
+    expect(png.transparency[:rgb]).to eq([0, 255, 0])
   end
 end
 
-# TODO: describe "When reading an indexed color PNG file wiih transparency (color type 3)"
+describe "When reading an indexed color PNG file with transparency (color type 3)" do
+  it "raises a not supported error" do
+    bin = File.binread("#{Prawn::DATADIR}/images/pal_bk.png")
+    expect { Prawn::Images::PNG.new(bin) }.to(
+      raise_error(Prawn::Errors::UnsupportedImageType))
+  end
+end
 
 describe "When reading an indexed color PNG file (color type 3)" do
-
   before(:each) do
     @filename = "#{Prawn::DATADIR}/images/indexed_color.png"
     @data_filename = "#{Prawn::DATADIR}/images/indexed_color.dat"
@@ -111,24 +112,23 @@ describe "When reading an indexed color PNG file (color type 3)" do
   it "should read the attributes from the header chunk correctly" do
     png = Prawn::Images::PNG.new(@img_data)
 
-    png.width.should == 150
-    png.height.should == 200
-    png.bits.should == 8
-    png.color_type.should == 3
-    png.compression_method.should == 0
-    png.filter_method.should == 0
-    png.interlace_method.should == 0
+    expect(png.width).to eq(150)
+    expect(png.height).to eq(200)
+    expect(png.bits).to eq(8)
+    expect(png.color_type).to eq(3)
+    expect(png.compression_method).to eq(0)
+    expect(png.filter_method).to eq(0)
+    expect(png.interlace_method).to eq(0)
   end
 
   it "should read the image data chunk correctly" do
     png = Prawn::Images::PNG.new(@img_data)
     data = Zlib::Inflate.inflate(File.binread(@data_filename))
-    png.img_data.should == data
+    expect(png.img_data).to eq(data)
   end
 end
 
 describe "When reading a greyscale+alpha PNG file (color type 4)" do
-
   before(:each) do
     @filename = "#{Prawn::DATADIR}/images/page_white_text.png"
     @color_data_filename = "#{Prawn::DATADIR}/images/page_white_text.color"
@@ -139,32 +139,31 @@ describe "When reading a greyscale+alpha PNG file (color type 4)" do
   it "should read the attributes from the header chunk correctly" do
     png = Prawn::Images::PNG.new(@img_data)
 
-    png.width.should == 16
-    png.height.should == 16
-    png.bits.should == 8
-    png.color_type.should == 4
-    png.compression_method.should == 0
-    png.filter_method.should == 0
-    png.interlace_method.should == 0
+    expect(png.width).to eq(16)
+    expect(png.height).to eq(16)
+    expect(png.bits).to eq(8)
+    expect(png.color_type).to eq(4)
+    expect(png.compression_method).to eq(0)
+    expect(png.filter_method).to eq(0)
+    expect(png.interlace_method).to eq(0)
   end
 
   it "should correctly return the raw image data (with no alpha channel) from the image data chunk" do
     png = Prawn::Images::PNG.new(@img_data)
     png.split_alpha_channel!
     data = File.binread(@color_data_filename)
-    png.img_data.should == data
+    expect(png.img_data).to eq(data)
   end
 
   it "should correctly extract the alpha channel data from the image data chunk" do
     png = Prawn::Images::PNG.new(@img_data)
     png.split_alpha_channel!
     data = File.binread(@alpha_data_filename)
-    png.alpha_channel.should == data
+    expect(png.alpha_channel).to eq(data)
   end
 end
 
 describe "When reading an RGB+alpha PNG file (color type 6)" do
-
   before(:each) do
     @filename = "#{Prawn::DATADIR}/images/dice.png"
     @color_data_filename = "#{Prawn::DATADIR}/images/dice.color"
@@ -175,32 +174,31 @@ describe "When reading an RGB+alpha PNG file (color type 6)" do
   it "should read the attributes from the header chunk correctly" do
     png = Prawn::Images::PNG.new(@img_data)
 
-    png.width.should == 320
-    png.height.should == 240
-    png.bits.should == 8
-    png.color_type.should == 6
-    png.compression_method.should == 0
-    png.filter_method.should == 0
-    png.interlace_method.should == 0
+    expect(png.width).to eq(320)
+    expect(png.height).to eq(240)
+    expect(png.bits).to eq(8)
+    expect(png.color_type).to eq(6)
+    expect(png.compression_method).to eq(0)
+    expect(png.filter_method).to eq(0)
+    expect(png.interlace_method).to eq(0)
   end
 
   it "should correctly return the raw image data (with no alpha channel) from the image data chunk" do
     png = Prawn::Images::PNG.new(@img_data)
     png.split_alpha_channel!
     data = File.binread(@color_data_filename)
-    png.img_data.should == data
+    expect(png.img_data).to eq(data)
   end
 
   it "should correctly extract the alpha channel data from the image data chunk" do
     png = Prawn::Images::PNG.new(@img_data)
     png.split_alpha_channel!
     data = File.binread(@alpha_data_filename)
-    png.alpha_channel.should == data
+    expect(png.alpha_channel).to eq(data)
   end
 end
 
 describe "When reading a 16bit RGB+alpha PNG file (color type 6)" do
-
   before(:each) do
     @filename = "#{Prawn::DATADIR}/images/16bit.png"
     @color_data_filename = "#{Prawn::DATADIR}/images/16bit.color"
@@ -212,26 +210,26 @@ describe "When reading a 16bit RGB+alpha PNG file (color type 6)" do
   it "should read the attributes from the header chunk correctly" do
     png = Prawn::Images::PNG.new(@img_data)
 
-    png.width.should == 32
-    png.height.should == 32
-    png.bits.should == 16
-    png.color_type.should == 6
-    png.compression_method.should == 0
-    png.filter_method.should == 0
-    png.interlace_method.should == 0
+    expect(png.width).to eq(32)
+    expect(png.height).to eq(32)
+    expect(png.bits).to eq(16)
+    expect(png.color_type).to eq(6)
+    expect(png.compression_method).to eq(0)
+    expect(png.filter_method).to eq(0)
+    expect(png.interlace_method).to eq(0)
   end
 
   it "should correctly return the raw image data (with no alpha channel) from the image data chunk" do
     png = Prawn::Images::PNG.new(@img_data)
     png.split_alpha_channel!
     data = File.binread(@color_data_filename)
-    png.img_data.should == data
+    expect(png.img_data).to eq(data)
   end
 
   it "should correctly extract the alpha channel data from the image data chunk" do
     png = Prawn::Images::PNG.new(@img_data)
     png.split_alpha_channel!
     data = File.binread(@alpha_data_filename)
-    png.alpha_channel.should == data
+    expect(png.alpha_channel).to eq(data)
   end
 end
