@@ -10,7 +10,7 @@ describe "Text::Box#nothing_printed?" do
                                     :height => 2,
                                     :document => @pdf)
     text_box.render
-    text_box.nothing_printed?.should be_true
+    expect(text_box.nothing_printed?).to be_true
   end
   it "should be_false when something printed" do
     create_pdf
@@ -19,7 +19,7 @@ describe "Text::Box#nothing_printed?" do
                                     :height => 14,
                                     :document => @pdf)
     text_box.render
-    text_box.nothing_printed?.should be_false
+    expect(text_box.nothing_printed?).to be_false
   end
 end
 
@@ -31,7 +31,7 @@ describe "Text::Box#everything_printed?" do
                                     :height => 14,
                                     :document => @pdf)
     text_box.render
-    text_box.everything_printed?.should be_false
+    expect(text_box.everything_printed?).to be_false
   end
   it "should be_true when everything printed" do
     create_pdf
@@ -39,19 +39,19 @@ describe "Text::Box#everything_printed?" do
     text_box = Prawn::Text::Box.new(string,
                                     :document => @pdf)
     text_box.render
-    text_box.everything_printed?.should be_true
+    expect(text_box.everything_printed?).to be_true
   end
 end
 
 describe "Text::Box#line_gap" do
-  it "should == the line gap of the font when using a single " +
+  it "should == the line gap of the font when using a single " \
     "font and font size" do
     create_pdf
     string = "Hello world, how are you?\nI'm fine, thank you."
     text_box = Prawn::Text::Box.new(string,
                                     :document => @pdf)
     text_box.render
-    text_box.line_gap.should be_within(0.0001).of(@pdf.font.line_gap)
+    expect(text_box.line_gap).to be_within(0.0001).of(@pdf.font.line_gap)
   end
 end
 
@@ -65,8 +65,8 @@ describe "Text::Box" do
                                     :document => @pdf)
     text_box.render
     text = PDF::Inspector::Text.analyze(@pdf.render)
-    text.strings[0].should == "?uoy era woh ,dlrow olleH"
-    text.strings[1].should == ".uoy knaht ,enif m'I"
+    expect(text.strings[0]).to eq("?uoy era woh ,dlrow olleH")
+    expect(text.strings[1]).to eq(".uoy knaht ,enif m'I")
   end
 
   it "should be able to reverse multi-byte text" do
@@ -78,7 +78,7 @@ describe "Text::Box" do
       @pdf.text "写个小"
     end
     text = PDF::Inspector::Text.analyze(@pdf.render)
-    text.strings[0].should == "小个写"
+    expect(text.strings[0]).to eq("小个写")
   end
 
   it "option should be able to override document-wide text direction" do
@@ -90,20 +90,19 @@ describe "Text::Box" do
                                     :direction => :ltr)
     text_box.render
     text = PDF::Inspector::Text.analyze(@pdf.render)
-    text.strings[0].should == "Hello world, how are you?"
-    text.strings[1].should == "I'm fine, thank you."
+    expect(text.strings[0]).to eq("Hello world, how are you?")
+    expect(text.strings[1]).to eq("I'm fine, thank you.")
   end
 end
 
 describe "Text::Box" do
-
   it "should be able to set leading document-wide" do
     create_pdf
     @pdf.default_leading(7)
     @pdf.default_leading = 7
     text_box = Prawn::Text::Box.new("hello world",
                                     :document => @pdf)
-    text_box.leading.should == 7
+    expect(text_box.leading).to eq(7)
   end
 
   it "option should be able to override document-wide leading" do
@@ -112,11 +111,10 @@ describe "Text::Box" do
     text_box = Prawn::Text::Box.new("hello world",
                                     :document => @pdf,
                                     :leading => 20)
-    text_box.leading.should == 20
+    expect(text_box.leading).to eq(20)
   end
-  it "should default to document-wide leading if no" +
+  it "should default to document-wide leading if no" \
     "leading option is provided" do
-
   end
 end
 
@@ -128,7 +126,7 @@ describe "Text::Box#render with :align => :justify" do
     text_box = Prawn::Text::Box.new(string, options)
     text_box.render
     contents = PDF::Inspector::Text.analyze(@pdf.render)
-    contents.word_spacing[0].should be > 0
+    expect(contents.word_spacing[0]).to be > 0
   end
   it "should not justify the last line of a paragraph" do
     create_pdf
@@ -137,42 +135,42 @@ describe "Text::Box#render with :align => :justify" do
     text_box = Prawn::Text::Box.new(string, options)
     text_box.render
     contents = PDF::Inspector::Text.analyze(@pdf.render)
-    contents.word_spacing.should be_empty
+    expect(contents.word_spacing).to be_empty
   end
 end
 
 describe "Text::Box" do
-  it "should only require enough space for the descender and the ascender " +
+  it "should only require enough space for the descender and the ascender " \
      "when determining whether a line can fit" do
     create_pdf
     text = "Oh hai text rect"
     options = { :document => @pdf, :height => @pdf.font.ascender + @pdf.font.descender }
     text_box = Prawn::Text::Box.new(text, options)
     text_box.render
-    text_box.text.should == "Oh hai text rect"
+    expect(text_box.text).to eq("Oh hai text rect")
 
     text = "Oh hai text rect\nOh hai text rect"
     options = { :document => @pdf, :height => @pdf.font.height + @pdf.font.ascender + @pdf.font.descender }
     text_box = Prawn::Text::Box.new(text, options)
     text_box.render
-    text_box.text.should == "Oh hai text rect\nOh hai text rect"
+    expect(text_box.text).to eq("Oh hai text rect\nOh hai text rect")
   end
 end
 
 describe "Text::Box#height without leading" do
-  it "should == the sum of the height of each line, " +
+  it "should == the sum of the height of each line, " \
     "not including the space below the last line" do
     create_pdf
     text = "Oh hai text rect.\nOh hai text rect."
     options = { :document => @pdf }
     text_box = Prawn::Text::Box.new(text, options)
     text_box.render
-    text_box.height.should be_within(0.001).of(@pdf.font.height * 2 - @pdf.font.line_gap)
+    expect(text_box.height).to be_within(0.001).of(@pdf.font.height * 2 - @pdf.font.line_gap)
   end
 end
 
 describe "Text::Box#height with leading" do
-  it "should == the sum of the height of each line plus leading, " +
+  it "should == the sum of the height of each line plus leading, " \
     "but not including the space below the last line" do
     create_pdf
     text = "Oh hai text rect.\nOh hai text rect."
@@ -180,7 +178,7 @@ describe "Text::Box#height with leading" do
     options = { :document => @pdf, :leading => leading }
     text_box = Prawn::Text::Box.new(text, options)
     text_box.render
-    text_box.height.should be_within(0.001).of((@pdf.font.height + leading) * 2 - @pdf.font.line_gap - leading)
+    expect(text_box.height).to be_within(0.001).of((@pdf.font.height + leading) * 2 - @pdf.font.line_gap - leading)
   end
 end
 
@@ -188,30 +186,30 @@ describe "Text::Box with :draw_text_callback" do
   before(:each) { create_pdf }
 
   it "hits the callback whenever text is drawn" do
-    draw_block = stub()
+    draw_block = stub
     draw_block.expects(:kick).with("this text is long enough to")
     draw_block.expects(:kick).with("span two lines")
 
     @pdf.text_box "this text is long enough to span two lines",
-      :width => 150,
-      :draw_text_callback => lambda { |text, _| draw_block.kick(text) }
+                  :width => 150,
+                  :draw_text_callback => lambda { |text, _| draw_block.kick(text) }
   end
 
   it "hits the callback once per fragment for :inline_format" do
-    draw_block = stub()
+    draw_block = stub
     draw_block.expects(:kick).with("this text has ")
     draw_block.expects(:kick).with("fancy")
     draw_block.expects(:kick).with(" formatting")
 
     @pdf.text_box "this text has <b>fancy</b> formatting",
-      :inline_format => true, :width => 500,
-      :draw_text_callback => lambda { |text, _| draw_block.kick(text) }
+                  :inline_format => true, :width => 500,
+                  :draw_text_callback => lambda { |text, _| draw_block.kick(text) }
   end
 
   it "does not call #draw_text!" do
     @pdf.expects(:draw_text!).never
     @pdf.text_box "some text", :width => 500,
-      :draw_text_callback => lambda { |_, _| }
+                               :draw_text_callback => lambda { |_, _| }
   end
 end
 
@@ -219,7 +217,7 @@ describe "Text::Box#valid_options" do
   it "should return an array" do
     create_pdf
     text_box = Prawn::Text::Box.new("", :document => @pdf)
-    text_box.valid_options.should be_a_kind_of(Array)
+    expect(text_box.valid_options).to be_a_kind_of(Array)
   end
 end
 
@@ -233,7 +231,7 @@ describe "Text::Box#render" do
     }
     text_box = Prawn::Text::Box.new(@text, @options)
     text_box.render
-    text_box.text.should == ""
+    expect(text_box.text).to eq("")
   end
   it "should draw content to the page" do
     create_pdf
@@ -242,7 +240,7 @@ describe "Text::Box#render" do
     text_box = Prawn::Text::Box.new(@text, @options)
     text_box.render
     text = PDF::Inspector::Text.analyze(@pdf.render)
-    text.strings.should_not be_empty
+    expect(text.strings).not_to be_empty
   end
   it "should not draw a transformation matrix" do
     create_pdf
@@ -251,7 +249,7 @@ describe "Text::Box#render" do
     text_box = Prawn::Text::Box.new(@text, @options)
     text_box.render
     matrices = PDF::Inspector::Graphics::Matrix.analyze(@pdf.render)
-    matrices.matrices.length.should == 0
+    expect(matrices.matrices.length).to eq(0)
   end
 end
 
@@ -264,7 +262,7 @@ describe "Text::Box#render(:single_line => true)" do
     text_box = Prawn::Text::Box.new(@text, @options)
     text_box.render
     text = PDF::Inspector::Text.analyze(@pdf.render)
-    text.strings.length.should == 1
+    expect(text.strings.length).to eq(1)
   end
 end
 
@@ -276,7 +274,7 @@ describe "Text::Box#render(:dry_run => true)" do
     text_box = Prawn::Text::Box.new(@text, @options)
     text_box.render(:dry_run => true)
     text = PDF::Inspector::Text.analyze(@pdf.render)
-    text.strings.should be_empty
+    expect(text.strings).to be_empty
   end
 
   it "subsequent calls to render should_not raise_error an ArgumentError exception" do
@@ -303,7 +301,7 @@ describe "Text::Box#render(:valign => :bottom)" do
     original_at = text_box.at.dup
 
     text_box.render(:dry_run => true)
-    text_box.at.should == original_at
+    expect(text_box.at).to eq(original_at)
   end
 end
 
@@ -320,7 +318,7 @@ describe "Text::Box#render(:valign => :center)" do
     original_at = text_box.at.dup
 
     text_box.render(:dry_run => true)
-    text_box.at.should == original_at
+    expect(text_box.at).to eq(original_at)
   end
 end
 
@@ -352,16 +350,16 @@ describe "Text::Box#render with :rotate option of 30)" do
       y = @y - @height / 2
       x_prime = x * @cos - y * @sin
       y_prime = x * @sin + y * @cos
-      matrices.matrices[0].should == [1, 0, 0, 1,
-                                      reduce_precision(x - x_prime),
-                                      reduce_precision(y - y_prime)]
-      matrices.matrices[1].should == [reduce_precision(@cos),
-                                      reduce_precision(@sin),
-                                      reduce_precision(-@sin),
-                                      reduce_precision(@cos), 0, 0]
+      expect(matrices.matrices[0]).to eq([1, 0, 0, 1,
+                                          reduce_precision(x - x_prime),
+                                          reduce_precision(y - y_prime)])
+      expect(matrices.matrices[1]).to eq([reduce_precision(@cos),
+                                          reduce_precision(@sin),
+                                          reduce_precision(-@sin),
+                                          reduce_precision(@cos), 0, 0])
 
       text = PDF::Inspector::Text.analyze(@pdf.render)
-      text.strings.should_not be_empty
+      expect(text.strings).not_to be_empty
     end
   end
   context ":rotate_around option of :upper_left" do
@@ -375,16 +373,16 @@ describe "Text::Box#render with :rotate option of 30)" do
       y = @y
       x_prime = x * @cos - y * @sin
       y_prime = x * @sin + y * @cos
-      matrices.matrices[0].should == [1, 0, 0, 1,
-                                      reduce_precision(x - x_prime),
-                                      reduce_precision(y - y_prime)]
-      matrices.matrices[1].should == [reduce_precision(@cos),
-                                      reduce_precision(@sin),
-                                      reduce_precision(-@sin),
-                                      reduce_precision(@cos), 0, 0]
+      expect(matrices.matrices[0]).to eq([1, 0, 0, 1,
+                                          reduce_precision(x - x_prime),
+                                          reduce_precision(y - y_prime)])
+      expect(matrices.matrices[1]).to eq([reduce_precision(@cos),
+                                          reduce_precision(@sin),
+                                          reduce_precision(-@sin),
+                                          reduce_precision(@cos), 0, 0])
 
       text = PDF::Inspector::Text.analyze(@pdf.render)
-      text.strings.should_not be_empty
+      expect(text.strings).not_to be_empty
     end
   end
   context "default :rotate_around" do
@@ -397,16 +395,16 @@ describe "Text::Box#render with :rotate option of 30)" do
       y = @y
       x_prime = x * @cos - y * @sin
       y_prime = x * @sin + y * @cos
-      matrices.matrices[0].should == [1, 0, 0, 1,
-                                      reduce_precision(x - x_prime),
-                                      reduce_precision(y - y_prime)]
-      matrices.matrices[1].should == [reduce_precision(@cos),
-                                      reduce_precision(@sin),
-                                      reduce_precision(-@sin),
-                                      reduce_precision(@cos), 0, 0]
+      expect(matrices.matrices[0]).to eq([1, 0, 0, 1,
+                                          reduce_precision(x - x_prime),
+                                          reduce_precision(y - y_prime)])
+      expect(matrices.matrices[1]).to eq([reduce_precision(@cos),
+                                          reduce_precision(@sin),
+                                          reduce_precision(-@sin),
+                                          reduce_precision(@cos), 0, 0])
 
       text = PDF::Inspector::Text.analyze(@pdf.render)
-      text.strings.should_not be_empty
+      expect(text.strings).not_to be_empty
     end
   end
   context ":rotate_around option of :upper_right" do
@@ -420,16 +418,16 @@ describe "Text::Box#render with :rotate option of 30)" do
       y = @y
       x_prime = x * @cos - y * @sin
       y_prime = x * @sin + y * @cos
-      matrices.matrices[0].should == [1, 0, 0, 1,
-                                      reduce_precision(x - x_prime),
-                                      reduce_precision(y - y_prime)]
-      matrices.matrices[1].should == [reduce_precision(@cos),
-                                      reduce_precision(@sin),
-                                      reduce_precision(-@sin),
-                                      reduce_precision(@cos), 0, 0]
+      expect(matrices.matrices[0]).to eq([1, 0, 0, 1,
+                                          reduce_precision(x - x_prime),
+                                          reduce_precision(y - y_prime)])
+      expect(matrices.matrices[1]).to eq([reduce_precision(@cos),
+                                          reduce_precision(@sin),
+                                          reduce_precision(-@sin),
+                                          reduce_precision(@cos), 0, 0])
 
       text = PDF::Inspector::Text.analyze(@pdf.render)
-      text.strings.should_not be_empty
+      expect(text.strings).not_to be_empty
     end
   end
   context ":rotate_around option of :lower_right" do
@@ -443,16 +441,16 @@ describe "Text::Box#render with :rotate option of 30)" do
       y = @y - @height
       x_prime = x * @cos - y * @sin
       y_prime = x * @sin + y * @cos
-      matrices.matrices[0].should == [1, 0, 0, 1,
-                                      reduce_precision(x - x_prime),
-                                      reduce_precision(y - y_prime)]
-      matrices.matrices[1].should == [reduce_precision(@cos),
-                                      reduce_precision(@sin),
-                                      reduce_precision(-@sin),
-                                      reduce_precision(@cos), 0, 0]
+      expect(matrices.matrices[0]).to eq([1, 0, 0, 1,
+                                          reduce_precision(x - x_prime),
+                                          reduce_precision(y - y_prime)])
+      expect(matrices.matrices[1]).to eq([reduce_precision(@cos),
+                                          reduce_precision(@sin),
+                                          reduce_precision(-@sin),
+                                          reduce_precision(@cos), 0, 0])
 
       text = PDF::Inspector::Text.analyze(@pdf.render)
-      text.strings.should_not be_empty
+      expect(text.strings).not_to be_empty
     end
   end
   context ":rotate_around option of :lower_left" do
@@ -466,16 +464,16 @@ describe "Text::Box#render with :rotate option of 30)" do
       y = @y - @height
       x_prime = x * @cos - y * @sin
       y_prime = x * @sin + y * @cos
-      matrices.matrices[0].should == [1, 0, 0, 1,
-                                      reduce_precision(x - x_prime),
-                                      reduce_precision(y - y_prime)]
-      matrices.matrices[1].should == [reduce_precision(@cos),
-                                      reduce_precision(@sin),
-                                      reduce_precision(-@sin),
-                                      reduce_precision(@cos), 0, 0]
+      expect(matrices.matrices[0]).to eq([1, 0, 0, 1,
+                                          reduce_precision(x - x_prime),
+                                          reduce_precision(y - y_prime)])
+      expect(matrices.matrices[1]).to eq([reduce_precision(@cos),
+                                          reduce_precision(@sin),
+                                          reduce_precision(-@sin),
+                                          reduce_precision(@cos), 0, 0])
 
       text = PDF::Inspector::Text.analyze(@pdf.render)
-      text.strings.should_not be_empty
+      expect(text.strings).not_to be_empty
     end
   end
 end
@@ -488,7 +486,7 @@ describe "Text::Box default height" do
     @text = "Oh hai\n" * 60
     text_box = Prawn::Text::Box.new(@text, :document => @pdf)
     text_box.render
-    text_box.height.should be_within(@pdf.font.height).of(target_height)
+    expect(text_box.height).to be_within(@pdf.font.height).of(target_height)
   end
 
   it "should use the margin-box bottom if only in a stretchy bbox" do
@@ -497,34 +495,34 @@ describe "Text::Box default height" do
       @text = "Oh hai\n" * 60
       text_box = Prawn::Text::Box.new(@text, :document => @pdf)
       text_box.render
-      text_box.height.should be_within(@pdf.font.height).of(target_height)
+      expect(text_box.height).to be_within(@pdf.font.height).of(target_height)
     end
   end
 
-  it "should use the parent-box bottom if in a stretchy bbox and " +
+  it "should use the parent-box bottom if in a stretchy bbox and " \
     "overflow is :expand, even with an explicit height"do
     @pdf.bounding_box([0, @pdf.cursor], :width => @pdf.bounds.width) do
       target_height = @pdf.y - @pdf.bounds.bottom
       @text = "Oh hai\n" * 60
       text_box = Prawn::Text::Box.new(@text, :document => @pdf,
-        :height => 100, :overflow => :expand)
+                                             :height => 100,
+                                             :overflow => :expand)
       text_box.render
-      text_box.height.should be_within(@pdf.font.height).of(target_height)
+      expect(text_box.height).to be_within(@pdf.font.height).of(target_height)
     end
   end
 
   it "should use the innermost non-stretchy bbox, not the margin box" do
     @pdf.bounding_box([0, @pdf.cursor], :width => @pdf.bounds.width,
-                      :height => 200) do
+                                        :height => 200) do
       @pdf.bounding_box([0, @pdf.cursor], :width => @pdf.bounds.width) do
         @text = "Oh hai\n" * 60
         text_box = Prawn::Text::Box.new(@text, :document => @pdf)
         text_box.render
-        text_box.height.should be_within(@pdf.font.height).of(200)
+        expect(text_box.height).to be_within(@pdf.font.height).of(200)
       end
     end
   end
-
 end
 
 describe "Text::Box default at" do
@@ -535,7 +533,7 @@ describe "Text::Box default at" do
     @options = { :document => @pdf }
     text_box = Prawn::Text::Box.new(@text, @options)
     text_box.render
-    text_box.at.should == target_at
+    expect(text_box.at).to eq(target_at)
   end
 end
 
@@ -550,24 +548,24 @@ describe "Text::Box with text than can fit in the box" do
     }
   end
 
-  it "printed text should match requested text, except that preceding and " +
-    "trailing white space will be stripped from each line, and newlines may " +
+  it "printed text should match requested text, except that preceding and " \
+    "trailing white space will be stripped from each line, and newlines may " \
     "be inserted" do
     text_box = Prawn::Text::Box.new("  " + @text, @options)
     text_box.render
-    text_box.text.gsub("\n", " ").should == @text.strip
+    expect(text_box.text.gsub("\n", " ")).to eq(@text.strip)
   end
 
   it "render should return an empty string because no text remains unprinted" do
     text_box = Prawn::Text::Box.new(@text, @options)
-    text_box.render.should == ""
+    expect(text_box.render).to eq("")
   end
 
   it "should be truncated when the leading is set high enough to prevent all the lines from being printed" do
     @options[:leading] = 40
     text_box = Prawn::Text::Box.new(@text, @options)
     text_box.render
-    text_box.text.gsub("\n", " ").should_not == @text.strip
+    expect(text_box.text.gsub("\n", " ")).not_to eq(@text.strip)
   end
 end
 
@@ -588,13 +586,13 @@ describe "Text::Box with text that fits exactly in the box" do
     expected_height = @options.delete(:height)
     text_box = Prawn::Text::Box.new(@text, @options)
     text_box.render
-    text_box.height.should be_within(0.0001).of(expected_height)
+    expect(text_box.height).to be_within(0.0001).of(expected_height)
   end
 
   it "should print everything" do
     text_box = Prawn::Text::Box.new(@text, @options)
     text_box.render
-    text_box.text.should == @text
+    expect(text_box.text).to eq(@text)
   end
 
   describe "with leading" do
@@ -606,14 +604,14 @@ describe "Text::Box with text that fits exactly in the box" do
       @options[:height] += @options[:leading] * @interlines
       text_box = Prawn::Text::Box.new(@text, @options)
       text_box.render
-      text_box.text.should == @text
+      expect(text_box.text).to eq(@text)
     end
 
     it "should overflow when insufficient height is added" do
       @options[:height] += @options[:leading] * @interlines - 1
       text_box = Prawn::Text::Box.new(@text, @options)
       text_box.render
-      text_box.text.should_not == @text
+      expect(text_box.text).not_to eq(@text)
     end
   end
 
@@ -626,14 +624,14 @@ describe "Text::Box with text that fits exactly in the box" do
       @options[:height] += @options[:leading] * @interlines
       text_box = Prawn::Text::Box.new(@text, @options)
       text_box.render
-      text_box.text.should == @text
+      expect(text_box.text).to eq(@text)
     end
 
     it "should overflow when too much height is removed" do
       @options[:height] += @options[:leading] * @interlines - 1
       text_box = Prawn::Text::Box.new(@text, @options)
       text_box.render
-      text_box.text.should_not == @text
+      expect(text_box.text).not_to eq(@text)
     end
   end
 end
@@ -662,33 +660,14 @@ describe "Text::Box printing UTF-8 string with higher bit characters" do
     it "unprinted text should be in UTF-8 encoding" do
       @pdf.font("Panic Sans")
       remaining_text = @text_box.render
-      remaining_text.should == @text
-    end
-
-    it "subsequent calls to Text::Box need not include the" +
-       " :skip_encoding => true option" do
-      @pdf.font("Panic Sans")
-      remaining_text = @text_box.render
-
-      # expect that calling text_box will not raise an encoding error
-      @pdf.text_box(remaining_text, :document => @pdf)
+      expect(remaining_text).to eq(@text)
     end
   end
 
   describe "when using an AFM font" do
-    it "unprinted text should be in WinAnsi encoding" do
+    it "unprinted text should be in UTF-8 encoding" do
       remaining_text = @text_box.render
-      remaining_text.should == @pdf.font.normalize_encoding(@text)
-    end
-    it "subsequent calls to Text::Box must include the" +
-       " :skip_encoding => true option" do
-      remaining_text = @text_box.render
-      lambda {
-        @pdf.text_box(remaining_text, :document => @pdf)
-      }.should raise_error(Prawn::Errors::IncompatibleStringEncoding)
-
-      @pdf.text_box(remaining_text, :skip_encoding => true,
-                                    :document => @pdf)
+      expect(remaining_text).to eq(@text)
     end
   end
 end
@@ -712,18 +691,18 @@ describe "Text::Box with more text than can fit in the box" do
     end
     it "should be truncated" do
       @text_box.render
-      @text_box.text.gsub("\n", " ").should_not == @text.strip
+      expect(@text_box.text.gsub("\n", " ")).not_to eq(@text.strip)
     end
     it "render should not return an empty string because some text remains unprinted" do
-      @text_box.render.should_not be_empty
+      expect(@text_box.render).not_to be_empty
     end
     it "#height should be no taller than the specified height" do
       @text_box.render
-      @text_box.height.should be <= @bounding_height
+      expect(@text_box.height).to be <= @bounding_height
     end
     it "#height should be within one font height of the specified height" do
       @text_box.render
-      @bounding_height.should be_within(@pdf.font.height).of(@text_box.height)
+      expect(@bounding_height).to be_within(@pdf.font.height).of(@text_box.height)
     end
     context "with :rotate option" do
       it "unrendered text should be the same as when not rotated" do
@@ -738,22 +717,22 @@ describe "Text::Box with more text than can fit in the box" do
         @options[:rotate] = rotate
         @options[:at] = [x, y]
         rotated_text_box = Prawn::Text::Box.new(@text, @options)
-        rotated_text_box.render.should == remaining_text
+        expect(rotated_text_box.render).to eq(remaining_text)
       end
     end
   end
 
   context "truncated with text and size taken from the manual" do
     it "should return the right text" do
-      @text = "This is the beginning of the text. It will be cut somewhere and " +
-        "the rest of the text will procede to be rendered this time by " +
+      @text = "This is the beginning of the text. It will be cut somewhere and " \
+        "the rest of the text will procede to be rendered this time by " \
         "calling another method." + " . " * 50
       @options[:width] = 300
       @options[:height] = 50
       @options[:size] = 18
       @text_box = Prawn::Text::Box.new(@text, @options)
       remaining_text = @text_box.render
-      remaining_text.should == "text will procede to be rendered this time by calling another method. .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  . "
+      expect(remaining_text).to eq("text will procede to be rendered this time by calling another method. .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  .  . ")
     end
   end
 
@@ -764,14 +743,14 @@ describe "Text::Box with more text than can fit in the box" do
     end
     it "height should expand to encompass all the text (but not exceed the height of the page)" do
       @text_box.render
-      @text_box.height.should > @bounding_height
+      expect(@text_box.height).to be > @bounding_height
     end
     it "should display the entire string (as long as there was space remaining on the page to print all the text)" do
       @text_box.render
-      @text_box.text.gsub("\n", " ").should == @text.strip
+      expect(@text_box.text.gsub("\n", " ")).to eq(@text.strip)
     end
     it "render should return an empty string because no text remains unprinted(as long as there was space remaining on the page to print all the text)" do
-      @text_box.render.should == ""
+      expect(@text_box.render).to eq("")
     end
   end
 
@@ -783,10 +762,10 @@ describe "Text::Box with more text than can fit in the box" do
     end
     it "should display the entire text" do
       @text_box.render
-      @text_box.text.gsub("\n", " ").should == @text.strip
+      expect(@text_box.text.gsub("\n", " ")).to eq(@text.strip)
     end
     it "render should return an empty string because no text remains unprinted" do
-      @text_box.render.should == ""
+      expect(@text_box.render).to eq("")
     end
   end
 
@@ -798,12 +777,12 @@ describe "Text::Box with more text than can fit in the box" do
       @text_box.render
 
       text = PDF::Inspector::Text.analyze(@pdf.render)
-      text.font_settings[0][:size].should == 10.1
+      expect(text.font_settings[0][:size]).to eq(10.1)
     end
   end
 end
 
-describe "Text::Box with enough space to fit the text but using the " +
+describe "Text::Box with enough space to fit the text but using the " \
   "shrink_to_fit overflow" do
   it "should not shrink the text when there is no need to" do
     create_pdf
@@ -819,7 +798,7 @@ describe "Text::Box with enough space to fit the text but using the " +
     @text_box.render
 
     text = PDF::Inspector::Text.analyze(@pdf.render)
-    text.font_settings[0][:size].should == 12
+    expect(text.font_settings[0][:size]).to eq(12)
   end
 end
 
@@ -836,11 +815,10 @@ describe "Text::Box with a solid block of Chinese characters" do
     @options[:overflow] = :truncate
     text_box = Prawn::Text::Box.new(@text, @options)
     text_box.render
-    text_box.text.gsub("\n", "").should == @text
+    expect(text_box.text.gsub("\n", "")).to eq(@text)
   end
 end
 
-
 describe "drawing bounding boxes" do
   before(:each) { create_pdf }
 
@@ -849,12 +827,10 @@ describe "drawing bounding boxes" do
 
     @pdf.text_box "Oh hai text box. " * 11, :height => @pdf.font.height * 10
 
-    @pdf.bounds.should == margin_box
-
+    expect(@pdf.bounds).to eq(margin_box)
   end
 end
 
-
 describe "Text::Box#render with :character_spacing option" do
   it "should draw the character spacing to the document" do
     create_pdf
@@ -863,7 +839,7 @@ describe "Text::Box#render with :character_spacing option" do
     text_box = Prawn::Text::Box.new(string, options)
     text_box.render
     contents = PDF::Inspector::Text.analyze(@pdf.render)
-    contents.character_spacing[0].should == 10
+    expect(contents.character_spacing[0]).to eq(10)
   end
   it "should take character spacing into account when wrapping" do
     create_pdf
@@ -874,7 +850,7 @@ describe "Text::Box#render with :character_spacing option" do
                                     :character_spacing => 10,
                                     :document => @pdf)
     text_box.render
-    text_box.text.should == "hello\nworld"
+    expect(text_box.text).to eq("hello\nworld")
   end
 end
 
@@ -893,7 +869,7 @@ describe "Text::Box wrapping" do
                                     :overflow => :expand,
                                     :document => @pdf)
     text_box.render
-    text_box.text.should == expect
+    expect(text_box.text).to eq(expect)
   end
 
   # white space was being stripped after the entire line was generated, meaning
@@ -901,7 +877,7 @@ describe "Text::Box wrapping" do
   # for other characters, so wrapping "hello hello" resulted in
   # "hello\n\nhello", rather than "hello\nhello"
   #
-  it "white space at beginning of line should not be taken into account when" +
+  it "white space at beginning of line should not be taken into account when" \
     " computing line width" do
     text = "hello hello"
     expect = "hello\nhello"
@@ -912,7 +888,7 @@ describe "Text::Box wrapping" do
                                     :overflow => :expand,
                                     :document => @pdf)
     text_box.render
-    text_box.text.should == expect
+    expect(text_box.text).to eq(expect)
   end
 
   it "should respect end of line when wrapping text" do
@@ -921,24 +897,24 @@ describe "Text::Box wrapping" do
 
     @pdf.font "Courier"
     text_box = Prawn::Text::Box.new(text,
-                                          :width    => 220,
-                                          :overflow => :expand,
-                                          :document => @pdf)
+                                    :width    => 220,
+                                    :overflow => :expand,
+                                    :document => @pdf)
     text_box.render
-    text_box.text.should == expect
+    expect(text_box.text).to eq(expect)
   end
 
   it "should respect multiple newlines when wrapping text" do
     text = "Please wrap only before THIS\n\nword. Don't wrap this"
-    expect= "Please wrap only before\nTHIS\n\nword. Don't wrap this"
+    expect = "Please wrap only before\nTHIS\n\nword. Don't wrap this"
 
     @pdf.font "Courier"
     text_box = Prawn::Text::Box.new(text,
-                                          :width    => 200,
-                                          :overflow => :expand,
-                                          :document => @pdf)
+                                    :width    => 200,
+                                    :overflow => :expand,
+                                    :document => @pdf)
     text_box.render
-    text_box.text.should == expect
+    expect(text_box.text).to eq(expect)
   end
 
   it "should respect multiple newlines when wrapping text when those newlines coincide with a line break" do
@@ -947,11 +923,11 @@ describe "Text::Box wrapping" do
 
     @pdf.font "Courier"
     text_box = Prawn::Text::Box.new(text,
-                                          :width    => 220,
-                                          :overflow => :expand,
-                                          :document => @pdf)
+                                    :width    => 220,
+                                    :overflow => :expand,
+                                    :document => @pdf)
     text_box.render
-    text_box.text.should == expect
+    expect(text_box.text).to eq(expect)
   end
 
   it "should respect initial newlines" do
@@ -960,11 +936,11 @@ describe "Text::Box wrapping" do
 
     @pdf.font "Courier"
     text_box = Prawn::Text::Box.new(text,
-                                          :width    => 220,
-                                          :overflow => :expand,
-                                          :document => @pdf)
+                                    :width    => 220,
+                                    :overflow => :expand,
+                                    :document => @pdf)
     text_box.render
-    text_box.text.should == expect
+    expect(text_box.text).to eq(expect)
   end
 
   it "should wrap lines comprised of a single word of the bounds when wrapping text" do
@@ -973,11 +949,11 @@ describe "Text::Box wrapping" do
 
     @pdf.font "Courier"
     text_box = Prawn::Text::Box.new(text,
-                                          :width    => 180,
-                                          :overflow => :expand,
-                                          :document => @pdf)
+                                    :width    => 180,
+                                    :overflow => :expand,
+                                    :document => @pdf)
     text_box.render
-    text_box.text.should == expect
+    expect(text_box.text).to eq(expect)
   end
 
   it "should wrap lines comprised of a single word of the bounds when wrapping text" do
@@ -985,31 +961,59 @@ describe "Text::Box wrapping" do
 
     @pdf.font "Courier"
     text_box = Prawn::Text::Box.new(text, :width => 180,
-                                           :overflow => :expand,
-                                           :document => @pdf)
+                                          :overflow => :expand,
+                                          :document => @pdf)
 
     text_box.render
 
     expected = "©" * 25 + "\n" + "©" * 5
     @pdf.font.normalize_encoding!(expected)
     expected = expected.force_encoding(Encoding::UTF_8)
-    text_box.text.should == expected
+    expect(text_box.text).to eq(expected)
   end
 
   it "should wrap non-unicode strings using single-byte word-wrapping" do
     text = "continúa esforzandote " * 5
     text_box = Prawn::Text::Box.new(text, :width => 180,
-                                     :document => @pdf)
+                                          :document => @pdf)
     text_box.render
     results_with_accent = text_box.text
 
     text = "continua esforzandote " * 5
     text_box = Prawn::Text::Box.new(text, :width => 180,
-                                     :document => @pdf)
+                                          :document => @pdf)
     text_box.render
     results_without_accent = text_box.text
 
-    first_line(results_with_accent).length.should == first_line(results_without_accent).length
+    expect(first_line(results_with_accent).length).to eq(first_line(results_without_accent).length)
+  end
+
+  it "should allow you to disable wrapping by char" do
+    text = "You_cannot_wrap_this_text_at_all_because_we_are_disabling_wrapping_by_char_and_there_are_no_word_breaks"
+
+    @pdf.font "Courier"
+    text_box = Prawn::Text::Box.new(text,
+                                    :width => 180,
+                                    :overflow => :shrink_to_fit,
+                                    :disable_wrap_by_char => true,
+                                    :document => @pdf)
+    expect { text_box.render }.to raise_error(Prawn::Errors::CannotFit)
+  end
+
+  it "should retain full words with :shrink_to_fit if char wrapping is disabled" do
+    text = "Wrapped_words"
+    expect = "Wrapped_words"
+
+    @pdf.font "Courier"
+    text_box = Prawn::Text::Box.new(text,
+                                    :width => 50,
+                                    :height => 50,
+                                    :size => 50,
+                                    :overflow => :shrink_to_fit,
+                                    :disable_wrap_by_char => true,
+                                    :document => @pdf)
+    text_box.render
+    expect(text_box.text).to eq(expect)
   end
 end
 
@@ -1021,7 +1025,7 @@ describe "Text::Box#render with :mode option" do
     text_box = Prawn::Text::Box.new(string, options)
     text_box.render
     contents = PDF::Inspector::Text.analyze(@pdf.render)
-    contents.text_rendering_mode.should == [2,0]
+    expect(contents.text_rendering_mode).to eq([2, 0])
   end
 end
 
